@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -13,18 +13,20 @@ import simplejson as json
 from functools import wraps
 
 import pgadmin.browser.server_groups.servers.databases as databases
-from flask import render_template, make_response, request, jsonify
-from flask_babel import gettext
+from flask import render_template, request, jsonify
+from flask_babelex import gettext
 from pgadmin.browser.collection import CollectionNodeModule
 from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db, \
     parse_priv_to_db
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
-    make_response as ajax_response
+    make_response as ajax_response, gone
 from pgadmin.utils.driver import get_driver
-from pgadmin.utils.ajax import gone
-
 from config import PG_DEFAULT_DRIVER
+from pgadmin.utils import IS_PY2
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class LanguageModule(CollectionNodeModule):
@@ -88,12 +90,21 @@ class LanguageModule(CollectionNodeModule):
     @property
     def script_load(self):
         """
-        Load the module script for language, when any of the database nodes are initialized.
+        Load the module script for language, when any of the database nodes
+        are initialized.
 
         Returns: node type of the server module.
         """
         return databases.DatabaseModule.NODE_TYPE
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 blueprint = LanguageModule(__name__)
 
@@ -102,30 +113,27 @@ class LanguageView(PGChildNodeView):
     """
     class LanguageView(PGChildNodeView)
 
-        A view class for Language node derived from PGChildNodeView. This class is
-        responsible for all the stuff related to view like updating language
-        node, showing properties, showing sql in sql pane.
+        A view class for Language node derived from PGChildNodeView.
+        This class is responsible for all the stuff related to view like
+        updating language node, showing properties, showing sql in sql pane.
 
     Methods:
     -------
     * __init__(**kwargs)
       - Method is used to initialize the LanguageView and it's base view.
 
-    * module_js()
-      - This property defines (if javascript) exists for this node.
-        Override this property for your own logic
-
     * check_precondition()
       - This function will behave as a decorator which will checks
         database connection before running view, it will also attaches
         manager,conn & template_path properties to self
 
     * list()
-      - This function is used to list all the language nodes within that collection.
+      - This function is used to list all the language nodes within that
+      collection.
 
     * nodes()
-      - This function will used to create all the child node within that collection.
-        Here it will create all the language node.
+      - This function will used to create all the child node within that
+      collection. Here it will create all the language node.
 
     * properties(gid, sid, did, lid)
       - This function will show the properties of the selected language node
@@ -140,25 +148,30 @@ class LanguageView(PGChildNodeView):
       - This function will delete the selected language node
 
     * msql(gid, sid, did, lid)
-      - This function is used to return modified SQL for the selected language node
+      - This function is used to return modified SQL for the selected
+      language node
 
     * get_sql(data, lid)
       - This function will generate sql from model data
 
     * get_functions(gid, sid, did)
-      - This function returns the handler and inline functions for the selected language node
+      - This function returns the handler and inline functions for the
+      selected language node
 
     * get_templates(gid, sid, did)
       - This function returns language templates.
 
     * sql(gid, sid, did, lid):
-      - This function will generate sql to show it in sql pane for the selected language node.
+      - This function will generate sql to show it in sql pane for the
+      selected language node.
 
     * dependents(gid, sid, did, lid):
-      - This function get the dependents and return ajax response for the language node.
+      - This function get the dependents and return ajax response for the
+      language node.
 
     * dependencies(self, gid, sid, did, lid):
-      - This function get the dependencies and return ajax response for the language node.
+      - This function get the dependencies and return ajax response for the
+      language node.
     """
 
     node_type = blueprint.node_type
@@ -175,7 +188,7 @@ class LanguageView(PGChildNodeView):
     operations = dict({
         'obj': [
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
-            {'get': 'list', 'post': 'create'}
+            {'get': 'list', 'post': 'create', 'delete': 'delete'}
         ],
         'nodes': [{'get': 'node'}, {'get': 'nodes'}],
         'sql': [{'get': 'sql'}],
@@ -183,16 +196,16 @@ class LanguageView(PGChildNodeView):
         'stats': [{'get': 'statistics'}],
         'dependency': [{'get': 'dependencies'}],
         'dependent': [{'get': 'dependents'}],
-        'module.js': [{}, {}, {'get': 'module_js'}],
         'get_functions': [{}, {'get': 'get_functions'}],
         'get_templates': [{}, {'get': 'get_templates'}],
-        'delete': [{'delete': 'delete'}]
+        'delete': [{'delete': 'delete'}, {'delete': 'delete'}]
     })
 
     def _init_(self, **kwargs):
         """
         Method is used to initialize the LanguageView and its base view.
-        Initialize all the variables create/used dynamically like conn, template_path.
+        Initialize all the variables create/used dynamically like conn,
+        template_path.
 
         Args:
             **kwargs:
@@ -203,18 +216,6 @@ class LanguageView(PGChildNodeView):
 
         super(LanguageView, self).__init__(**kwargs)
 
-    def module_js(self):
-        """
-        This property defines whether javascript exists for this node.
-        """
-        return make_response(
-            render_template(
-                "languages/js/languages.js",
-                _=gettext
-            ),
-            200, {'Content-Type': 'application/x-javascript'}
-        )
-
     def check_precondition(f):
         """
         This function will behave as a decorator which will check the
@@ -230,7 +231,11 @@ class LanguageView(PGChildNodeView):
             self.manager = self.driver.connection_manager(kwargs['sid'])
             self.conn = self.manager.connection(did=kwargs['did'])
             # Set the template path for the SQL scripts
-            self.template_path = "languages/sql/#{0}#".format(self.manager.version)
+            self.template_path = (
+                "languages/sql/#gpdb#{0}#".format(self.manager.version) if
+                self.manager.server_type == 'gpdb' else
+                "languages/sql/#{0}#".format(self.manager.version)
+            )
 
             return f(*args, **kwargs)
 
@@ -239,7 +244,8 @@ class LanguageView(PGChildNodeView):
     @check_precondition
     def list(self, gid, sid, did):
         """
-        This function is used to list all the language nodes within that collection.
+        This function is used to list all the language nodes within that
+        collection.
 
         Args:
             gid: Server Group ID
@@ -259,8 +265,8 @@ class LanguageView(PGChildNodeView):
     @check_precondition
     def nodes(self, gid, sid, did):
         """
-        This function is used to create all the child nodes within the collection.
-        Here it will create all the language nodes.
+        This function is used to create all the child nodes within the
+        collection. Here it will create all the language nodes.
 
         Args:
             gid: Server Group ID
@@ -328,7 +334,10 @@ class LanguageView(PGChildNodeView):
             did: Database ID
             lid: Language ID
         """
-        sql = render_template("/".join([self.template_path, 'properties.sql']), lid=lid)
+        sql = render_template(
+            "/".join([self.template_path, 'properties.sql']),
+            lid=lid
+        )
         status, res = self.conn.execute_dict(sql)
 
         if not status:
@@ -339,7 +348,10 @@ class LanguageView(PGChildNodeView):
                 gettext("Could not find the language information.")
             )
 
-        sql = render_template("/".join([self.template_path, 'acl.sql']), lid=lid)
+        sql = render_template(
+            "/".join([self.template_path, 'acl.sql']),
+            lid=lid
+        )
         status, result = self.conn.execute_dict(sql)
         if not status:
             return internal_server_error(errormsg=result)
@@ -349,7 +361,13 @@ class LanguageView(PGChildNodeView):
             res['rows'][0]['lanacl'] = dict()
             res['rows'][0]['lanacl']['grantee'] = 'PUBLIC'
             res['rows'][0]['lanacl']['grantor'] = res['rows'][0]['lanowner']
-            res['rows'][0]['lanacl']['privileges'] = [{'privilege_type': 'U', 'privilege': True, 'with_grant': False}]
+            res['rows'][0]['lanacl']['privileges'] = [
+                {
+                    'privilege_type': 'U',
+                    'privilege': True,
+                    'with_grant': False
+                }
+            ]
         else:
             for row in result['rows']:
                 priv = parse_priv_from_db(row)
@@ -359,7 +377,8 @@ class LanguageView(PGChildNodeView):
                     res['rows'][0][row['deftype']] = [priv]
 
         seclabels = []
-        if 'seclabels' in res['rows'][0] and res['rows'][0]['seclabels'] is not None:
+        if 'seclabels' in res['rows'][0] and \
+                res['rows'][0]['seclabels'] is not None:
             import re
             for sec in res['rows'][0]['seclabels']:
                 sec = re.search(r'([^=]+)=(.*$)', sec)
@@ -392,6 +411,9 @@ class LanguageView(PGChildNodeView):
 
         try:
             sql, name = self.get_sql(data, lid)
+            # Most probably this is due to error
+            if not isinstance(sql, (str, unicode)):
+                return sql
             sql = sql.strip('\n').strip(' ')
             status, res = self.conn.execute_dict(sql)
             if not status:
@@ -445,8 +467,10 @@ class LanguageView(PGChildNodeView):
             if not status:
                 return internal_server_error(errormsg=res)
 
-            sql = render_template("/".join([self.template_path, 'properties.sql']),
-                                  lanname=data['name'], conn=self.conn)
+            sql = render_template(
+                "/".join([self.template_path, 'properties.sql']),
+                lanname=data['name'], conn=self.conn
+            )
 
             status, r_set = self.conn.execute_dict(sql)
             if not status:
@@ -466,7 +490,7 @@ class LanguageView(PGChildNodeView):
             return internal_server_error(errormsg=str(e))
 
     @check_precondition
-    def delete(self, gid, sid, did, lid):
+    def delete(self, gid, sid, did, lid=None):
         """
         This function will drop the language object
 
@@ -476,6 +500,13 @@ class LanguageView(PGChildNodeView):
             did: Database ID
             lid: Language ID
         """
+        if lid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [lid]}
+
         if self.cmd == 'delete':
             # This is a cascade operation
             cascade = True
@@ -483,30 +514,30 @@ class LanguageView(PGChildNodeView):
             cascade = False
 
         try:
-            # Get name for language from lid
-            sql = render_template("/".join([self.template_path, 'delete.sql']), lid=lid, conn=self.conn)
-            status, lname = self.conn.execute_scalar(sql)
+            for lid in data['ids']:
+                # Get name for language from lid
+                sql = render_template(
+                    "/".join([self.template_path, 'delete.sql']),
+                    lid=lid, conn=self.conn
+                )
+                status, lname = self.conn.execute_scalar(sql)
 
-            if not status:
-                return internal_server_error(errormsg=lname)
+                if not status:
+                    return internal_server_error(errormsg=lname)
 
-            # drop language
-            sql = render_template("/".join([self.template_path, 'delete.sql']), lname=lname,
-                                  cascade=cascade, conn=self.conn)
-            status, res = self.conn.execute_scalar(sql)
+                # drop language
+                sql = render_template(
+                    "/".join([self.template_path, 'delete.sql']),
+                    lname=lname, cascade=cascade, conn=self.conn
+                )
+                status, res = self.conn.execute_scalar(sql)
 
-            if not status:
-                return internal_server_error(errormsg=res)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
             return make_json_response(
                 success=1,
-                info=gettext("Language dropped"),
-                data={
-                    'id': lid,
-                    'did': did,
-                    'sid': sid,
-                    'gid': gid,
-                }
+                info=gettext("Language dropped")
             )
 
         except Exception as e:
@@ -515,7 +546,8 @@ class LanguageView(PGChildNodeView):
     @check_precondition
     def msql(self, gid, sid, did, lid=None):
         """
-        This function is used to return modified SQL for the selected language node.
+        This function is used to return modified SQL for the selected
+        language node.
 
         Args:
             gid: Server Group ID
@@ -531,13 +563,16 @@ class LanguageView(PGChildNodeView):
                 data[k] = v
         try:
             sql, name = self.get_sql(data, lid)
+            # Most probably this is due to error
+            if not isinstance(sql, (str, unicode)):
+                return sql
             if sql == '':
                 sql = "--modified SQL"
 
             return make_json_response(
                 data=sql,
                 status=200
-                )
+            )
         except Exception as e:
             return internal_server_error(errormsg=str(e))
 
@@ -554,7 +589,9 @@ class LanguageView(PGChildNodeView):
         ]
 
         if lid is not None:
-            sql = render_template("/".join([self.template_path, 'properties.sql']), lid=lid)
+            sql = render_template(
+                "/".join([self.template_path, 'properties.sql']), lid=lid
+            )
             status, res = self.conn.execute_dict(sql)
             if not status:
                 return internal_server_error(errormsg=res)
@@ -567,19 +604,28 @@ class LanguageView(PGChildNodeView):
             for key in ['lanacl']:
                 if key in data and data[key] is not None:
                     if 'added' in data[key]:
-                        data[key]['added'] = parse_priv_to_db(data[key]['added'], ["U"])
+                        data[key]['added'] = parse_priv_to_db(
+                            data[key]['added'], ["U"]
+                        )
                     if 'changed' in data[key]:
-                        data[key]['changed'] = parse_priv_to_db(data[key]['changed'], ["U"])
+                        data[key]['changed'] = parse_priv_to_db(
+                            data[key]['changed'], ["U"]
+                        )
                     if 'deleted' in data[key]:
-                        data[key]['deleted'] = parse_priv_to_db(data[key]['deleted'], ["U"])
+                        data[key]['deleted'] = parse_priv_to_db(
+                            data[key]['deleted'], ["U"]
+                        )
 
             old_data = res['rows'][0]
             for arg in required_args:
                 if arg not in data:
                     data[arg] = old_data[arg]
-            sql = render_template("/".join([self.template_path, 'update.sql']), data=data,
-                                  o_data=old_data, conn=self.conn)
-            return sql.strip('\n'), data['name'] if 'name' in data else old_data['name']
+            sql = render_template(
+                "/".join([self.template_path, 'update.sql']),
+                data=data, o_data=old_data, conn=self.conn
+            )
+            return sql.strip('\n'), data['name'] if 'name' in data \
+                else old_data['name']
         else:
 
             if 'lanacl' in data:
@@ -589,11 +635,11 @@ class LanguageView(PGChildNodeView):
                                   data=data, conn=self.conn)
             return sql.strip('\n'), data['name']
 
-
     @check_precondition
     def get_functions(self, gid, sid, did):
         """
-        This function returns the handler and inline functions for the selected language node.
+        This function returns the handler and inline functions for the
+        selected language node.
 
         Args:
             gid: Server Group ID
@@ -631,7 +677,8 @@ class LanguageView(PGChildNodeView):
     @check_precondition
     def sql(self, gid, sid, did, lid):
         """
-        This function will generate sql to show in the sql pane for the selected language node.
+        This function will generate sql to show in the sql pane for the
+        selected language node.
 
         Args:
             gid: Server Group ID
@@ -639,15 +686,26 @@ class LanguageView(PGChildNodeView):
             did: Database ID
             lid: Language ID
         """
-        sql = render_template("/".join([self.template_path, 'properties.sql']), lid=lid)
+        sql = render_template(
+            "/".join([self.template_path, 'properties.sql']),
+            lid=lid
+        )
         status, res = self.conn.execute_dict(sql)
         if not status:
             return internal_server_error(errormsg=res)
 
+        if len(res['rows']) == 0:
+            return gone(
+                gettext("Could not find the language information.")
+            )
+
         # Making copy of output for future use
         old_data = dict(res['rows'][0])
 
-        sql = render_template("/".join([self.template_path, 'acl.sql']), lid=lid)
+        sql = render_template(
+            "/".join([self.template_path, 'acl.sql']),
+            lid=lid
+        )
         status, result = self.conn.execute_dict(sql)
         if not status:
             return internal_server_error(errormsg=result)
@@ -670,7 +728,10 @@ class LanguageView(PGChildNodeView):
                 })
 
         old_data['seclabels'] = seclabels
-        sql = render_template("/".join([self.template_path, 'sqlpane.sql']), data=old_data, conn=self.conn)
+        sql = render_template(
+            "/".join([self.template_path, 'sqlpane.sql']),
+            data=old_data, conn=self.conn
+        )
 
         return ajax_response(response=sql.strip('\n'))
 
