@@ -2,30 +2,35 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
 
 """Implements Package Node"""
 import re
-import simplejson as json
 from functools import wraps
 
-import pgadmin.browser.server_groups.servers.databases as database
+import simplejson as json
 from flask import render_template, make_response, request, jsonify
-from flask_babel import gettext as _
+from flask_babelex import gettext as _
+
+import pgadmin.browser.server_groups.servers.databases as database
+from config import PG_DEFAULT_DRIVER
 from pgadmin.browser.server_groups.servers.databases.schemas.utils \
     import SchemaChildModule
 from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db, \
     parse_priv_to_db
 from pgadmin.browser.utils import PGChildNodeView
+from pgadmin.utils import IS_PY2
 from pgadmin.utils.ajax import make_json_response, \
-    make_response as ajax_response, internal_server_error
-from pgadmin.utils.ajax import precondition_required, gone
+    make_response as ajax_response, internal_server_error, \
+    precondition_required, gone
 from pgadmin.utils.driver import get_driver
 
-from config import PG_DEFAULT_DRIVER
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class PackageModule(SchemaChildModule):
@@ -94,9 +99,9 @@ class PackageView(PGChildNodeView):
     operations = dict({
         'obj': [
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
-            {'get': 'list', 'post': 'create'}
+            {'get': 'list', 'post': 'create', 'delete': 'delete'}
         ],
-        'delete': [{'delete': 'delete'}],
+        'delete': [{'delete': 'delete'}, {'delete': 'delete'}],
         'children': [{'get': 'children'}],
         'nodes': [{'get': 'nodes'}, {'get': 'nodes'}],
         'sql': [{'get': 'sql'}],
@@ -142,10 +147,11 @@ class PackageView(PGChildNodeView):
                 if not self.conn.connected():
                     return precondition_required(
                         _(
-                            "Connection to the server has been lost!"
+                            "Connection to the server has been lost."
                         )
                     )
-                self.template_path = 'package/ppas/#{0}#'.format(self.manager.version)
+                self.template_path = 'package/ppas/#{0}#'.format(
+                    self.manager.version)
 
                 SQL = render_template(
                     "/".join([self.template_path, 'get_schema.sql']),
@@ -168,7 +174,8 @@ class PackageView(PGChildNodeView):
     @check_precondition(action='list')
     def list(self, gid, sid, did, scid):
         """
-        This function is used to list all the package nodes within the collection.
+        This function is used to list all the package nodes within the
+        collection.
 
         Args:
           gid: Server Group ID
@@ -179,7 +186,8 @@ class PackageView(PGChildNodeView):
         Returns:
 
         """
-        SQL = render_template("/".join([self.template_path, 'properties.sql']), scid=scid)
+        SQL = render_template("/".join([self.template_path, 'properties.sql']),
+                              scid=scid)
         status, res = self.conn.execute_dict(SQL)
 
         if not status:
@@ -192,7 +200,8 @@ class PackageView(PGChildNodeView):
     @check_precondition(action='nodes')
     def nodes(self, gid, sid, did, scid, pkgid=None):
         """
-        This function is used to create all the child nodes within the collection.
+        This function is used to create all the child nodes within the
+        collection.
         Here it will create all the package nodes.
 
         Args:
@@ -217,7 +226,7 @@ class PackageView(PGChildNodeView):
         if pkgid is not None:
             if len(rset['rows']) == 0:
                 return gone(
-                     errormsg=_("Could not find the package.")
+                    errormsg=_("Could not find the package.")
                 )
 
             row = rset['rows'][0]
@@ -244,6 +253,49 @@ class PackageView(PGChildNodeView):
             status=200
         )
 
+    @check_precondition(action='node')
+    def node(self, gid, sid, did, scid, pkgid):
+        """
+        This function will show the selected package node.
+
+        Args:
+          gid: Server Group ID
+          sid: Server ID
+          did: Database ID
+          scid: Schema ID
+          pkgid: Package ID
+
+        Returns:
+
+        """
+        SQL = render_template(
+            "/".join([self.template_path, 'properties.sql']),
+            scid=scid, pkgid=pkgid
+        )
+        status, rset = self.conn.execute_dict(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=res)
+
+        if len(rset['rows']) == 0:
+            return gone(
+                errormsg=_("Could not find the package in the database.")
+            )
+
+        for row in rset['rows']:
+            res.append(
+                self.blueprint.generate_browser_node(
+                    row['oid'],
+                    scid,
+                    row['name'],
+                    icon="icon-%s" % self.node_type
+                ))
+
+        return make_json_response(
+            data=res,
+            status=200
+        )
+
     @check_precondition(action='properties')
     def properties(self, gid, sid, did, scid, pkgid):
         """
@@ -259,7 +311,8 @@ class PackageView(PGChildNodeView):
         Returns:
 
         """
-        SQL = render_template("/".join([self.template_path, 'properties.sql']), scid=scid, pkgid=pkgid)
+        SQL = render_template("/".join([self.template_path, 'properties.sql']),
+                              scid=scid, pkgid=pkgid)
         status, res = self.conn.execute_dict(SQL)
 
         if not status:
@@ -270,8 +323,10 @@ class PackageView(PGChildNodeView):
                 errormsg=_("Could not find the package in the database.")
             )
 
-        res['rows'][0]['pkgheadsrc'] = self.get_inner(res['rows'][0]['pkgheadsrc'])
-        res['rows'][0]['pkgbodysrc'] = self.get_inner(res['rows'][0]['pkgbodysrc'])
+        res['rows'][0]['pkgheadsrc'] = self.get_inner(
+            res['rows'][0]['pkgheadsrc'])
+        res['rows'][0]['pkgbodysrc'] = self.get_inner(
+            res['rows'][0]['pkgbodysrc'])
 
         SQL = render_template("/".join([self.template_path, 'acl.sql']),
                               scid=scid,
@@ -357,7 +412,7 @@ class PackageView(PGChildNodeView):
         )
 
     @check_precondition(action='delete')
-    def delete(self, gid, sid, did, scid, pkgid):
+    def delete(self, gid, sid, did, scid, pkgid=None):
         """
         This function will drop the object
 
@@ -371,6 +426,14 @@ class PackageView(PGChildNodeView):
         Returns:
 
         """
+
+        if pkgid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [pkgid]}
+
         # Below will decide if it's simple drop or drop with cascade call
         if self.cmd == 'delete':
             # This is a cascade operation
@@ -379,42 +442,40 @@ class PackageView(PGChildNodeView):
             cascade = False
 
         try:
-            SQL = render_template("/".join([self.template_path, 'properties.sql']), scid=scid, pkgid=pkgid)
-            status, res = self.conn.execute_dict(SQL)
-            if not status:
-                return internal_server_error(errormsg=res)
+            for pkgid in data['ids']:
+                SQL = render_template(
+                    "/".join([self.template_path, 'properties.sql']),
+                    scid=scid,
+                    pkgid=pkgid)
+                status, res = self.conn.execute_dict(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
-            if not res['rows']:
-                return make_json_response(
-                    success=0,
-                    errormsg=_(
-                        'Error: Object not found.'
-                    ),
-                    info=_(
-                        'The specified package could not be found.\n'
+                if not res['rows']:
+                    return make_json_response(
+                        success=0,
+                        errormsg=_(
+                            'Error: Object not found.'
+                        ),
+                        info=_(
+                            'The specified package could not be found.\n'
+                        )
                     )
-                )
 
-            res['rows'][0]['schema'] = self.schema
+                res['rows'][0]['schema'] = self.schema
 
-            SQL = render_template("/".join([self.template_path, 'delete.sql']),
-                                  data=res['rows'][0],
-                                  cascade=cascade)
+                SQL = render_template("/".join([self.template_path,
+                                                'delete.sql']),
+                                      data=res['rows'][0],
+                                      cascade=cascade)
 
-            status, res = self.conn.execute_scalar(SQL)
-            if not status:
-                return internal_server_error(errormsg=res)
+                status, res = self.conn.execute_scalar(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
             return make_json_response(
                 success=1,
-                info=_("Packge dropped"),
-                data={
-                    'id': pkgid,
-                    'scid': scid,
-                    'sid': sid,
-                    'gid': gid,
-                    'did': did
-                }
+                info=_("Package dropped")
             )
 
         except Exception as e:
@@ -440,6 +501,10 @@ class PackageView(PGChildNodeView):
         )
 
         SQL, name = self.getSQL(gid, sid, did, data, scid, pkgid)
+        # Most probably this is due to error
+        if not isinstance(SQL, (str, unicode)):
+            return SQL
+
         SQL = SQL.strip('\n').strip(' ')
         status, res = self.conn.execute_scalar(SQL)
         if not status:
@@ -491,6 +556,10 @@ class PackageView(PGChildNodeView):
                     )
 
         SQL, name = self.getSQL(gid, sid, did, data, scid, pkgid)
+        # Most probably this is due to error
+        if not isinstance(SQL, (str, unicode)):
+            return SQL
+
         SQL = SQL.strip('\n').strip(' ')
         if SQL == '':
             SQL = "--modified SQL"
@@ -517,13 +586,21 @@ class PackageView(PGChildNodeView):
 
         if pkgid is not None:
             data['schema'] = self.schema
-            SQL = render_template("/".join([self.template_path, 'properties.sql']), scid=scid, pkgid=pkgid)
+            SQL = render_template(
+                "/".join([self.template_path, 'properties.sql']), scid=scid,
+                pkgid=pkgid)
             status, res = self.conn.execute_dict(SQL)
             if not status:
                 return internal_server_error(errormsg=res)
+            if len(res['rows']) == 0:
+                return gone(
+                    errormsg=_("Could not find the package in the database.")
+                )
 
-            res['rows'][0]['pkgheadsrc'] = self.get_inner(res['rows'][0]['pkgheadsrc'])
-            res['rows'][0]['pkgbodysrc'] = self.get_inner(res['rows'][0]['pkgbodysrc'])
+            res['rows'][0]['pkgheadsrc'] = self.get_inner(
+                res['rows'][0]['pkgheadsrc'])
+            res['rows'][0]['pkgbodysrc'] = self.get_inner(
+                res['rows'][0]['pkgbodysrc'])
 
             SQL = render_template("/".join([self.template_path, 'acl.sql']),
                                   scid=scid,
@@ -545,11 +622,14 @@ class PackageView(PGChildNodeView):
             for key in ['pkgacl']:
                 if key in data and data[key] is not None:
                     if 'added' in data[key]:
-                        data[key]['added'] = parse_priv_to_db(data[key]['added'], self.acl)
+                        data[key]['added'] = parse_priv_to_db(
+                            data[key]['added'], self.acl)
                     if 'changed' in data[key]:
-                        data[key]['changed'] = parse_priv_to_db(data[key]['changed'], self.acl)
+                        data[key]['changed'] = parse_priv_to_db(
+                            data[key]['changed'], self.acl)
                     if 'deleted' in data[key]:
-                        data[key]['deleted'] = parse_priv_to_db(data[key]['deleted'], self.acl)
+                        data[key]['deleted'] = parse_priv_to_db(
+                            data[key]['deleted'], self.acl)
 
             # If name is not present with in update data then copy it
             # from old data
@@ -565,7 +645,8 @@ class PackageView(PGChildNodeView):
             if 'pkgacl' in data:
                 data['pkgacl'] = parse_priv_to_db(data['pkgacl'], self.acl)
 
-            SQL = render_template("/".join([self.template_path, 'create.sql']), data=data, conn=self.conn)
+            SQL = render_template("/".join([self.template_path, 'create.sql']),
+                                  data=data, conn=self.conn)
 
             return SQL, data['name']
 
@@ -582,13 +663,21 @@ class PackageView(PGChildNodeView):
             pkgid: Package ID
         """
         try:
-            SQL = render_template("/".join([self.template_path, 'properties.sql']), scid=scid, pkgid=pkgid)
+            SQL = render_template(
+                "/".join([self.template_path, 'properties.sql']), scid=scid,
+                pkgid=pkgid)
             status, res = self.conn.execute_dict(SQL)
             if not status:
                 return internal_server_error(errormsg=res)
+            if len(res['rows']) == 0:
+                return gone(
+                    errormsg=_("Could not find the package in the database.")
+                )
 
-            res['rows'][0]['pkgheadsrc'] = self.get_inner(res['rows'][0]['pkgheadsrc'])
-            res['rows'][0]['pkgbodysrc'] = self.get_inner(res['rows'][0]['pkgbodysrc'])
+            res['rows'][0]['pkgheadsrc'] = self.get_inner(
+                res['rows'][0]['pkgheadsrc'])
+            res['rows'][0]['pkgbodysrc'] = self.get_inner(
+                res['rows'][0]['pkgbodysrc'])
 
             SQL = render_template("/".join([self.template_path, 'acl.sql']),
                                   scid=scid,
@@ -603,7 +692,11 @@ class PackageView(PGChildNodeView):
                 res['rows'][0].setdefault(row['deftype'], []).append(priv)
 
             result = res['rows'][0]
-            sql, name = self.getSQL(gid, sid, did, result, scid)
+            sql, name = self.getSQL(gid, sid, did, result, scid, pkgid)
+            # Most probably this is due to error
+            if not isinstance(sql, (str, unicode)):
+                return sql
+
             sql = sql.strip('\n').strip(' ')
 
             sql_header = u"-- Package: {}\n\n-- ".format(
@@ -620,7 +713,7 @@ class PackageView(PGChildNodeView):
             return ajax_response(response=sql)
 
         except Exception as e:
-                return internal_server_error(errormsg=str(e))
+            return internal_server_error(errormsg=str(e))
 
     @check_precondition(action="dependents")
     def dependents(self, gid, sid, did, scid, pkgid):
@@ -679,4 +772,5 @@ class PackageView(PGChildNodeView):
 
         return sql[start:end].strip("\n")
 
+
 PackageView.register_node_view(blueprint)
