@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -14,15 +14,20 @@ from functools import wraps
 
 import pgadmin.browser.server_groups.servers.databases as database
 from flask import render_template, request, jsonify
-from flask_babel import gettext
+from flask_babelex import gettext
 from pgadmin.browser.collection import CollectionNodeModule
+from pgadmin.browser.server_groups.servers.databases.schemas.tables.\
+    partitions import backend_supported
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
-    make_response as ajax_response
+    make_response as ajax_response, gone
+from pgadmin.utils.compile_template_name import compile_template_path
 from pgadmin.utils.driver import get_driver
-
 from config import PG_DEFAULT_DRIVER
-from pgadmin.utils.ajax import gone
+from pgadmin.utils import IS_PY2
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class IndexesModule(CollectionNodeModule):
@@ -70,12 +75,19 @@ class IndexesModule(CollectionNodeModule):
         if super(IndexesModule, self).BackendSupported(manager, **kwargs):
             conn = manager.connection(did=kwargs['did'])
 
+            # If PG version > 100000 and < 110000 then index is
+            # not supported for partitioned table.
+            if 'tid' in kwargs and 100000 <= manager.version < 110000:
+                return not backend_supported(self, manager, **kwargs)
+
             if 'vid' not in kwargs:
                 return True
 
             template_path = 'index/sql/#{0}#'.format(manager.version)
-            SQL = render_template("/".join(
-                [template_path, 'backend_support.sql']), vid=kwargs['vid'])
+            SQL = render_template(
+                "/".join([template_path, 'backend_support.sql']),
+                vid=kwargs['vid']
+            )
             status, res = conn.execute_scalar(SQL)
 
             # check if any errors
@@ -109,6 +121,14 @@ class IndexesModule(CollectionNodeModule):
         """
         return False
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 blueprint = IndexesModule(__name__)
 
@@ -191,9 +211,9 @@ class IndexesView(PGChildNodeView):
     operations = dict({
         'obj': [
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
-            {'get': 'list', 'post': 'create'}
+            {'get': 'list', 'post': 'create', 'delete': 'delete'}
         ],
-        'delete': [{'delete': 'delete'}],
+        'delete': [{'delete': 'delete'}, {'delete': 'delete'}],
         'children': [{'get': 'children'}],
         'nodes': [{'get': 'node'}, {'get': 'nodes'}],
         'sql': [{'get': 'sql'}],
@@ -232,14 +252,19 @@ class IndexesView(PGChildNodeView):
                 kwargs['did'] in self.manager.db_info else 0
 
             # we will set template path for sql scripts
-            self.template_path = 'index/sql/#{0}#'.format(self.manager.version)
+            self.template_path = compile_template_path(
+                'index/sql/',
+                self.manager.server_type,
+                self.manager.version
+            )
 
             # We need parent's name eg table name and schema name
             # when we create new index in update we can fetch it using
             # property sql
-            SQL = render_template("/".join([self.template_path,
-                                            'get_parent.sql']),
-                                  tid=kwargs['tid'])
+            SQL = render_template(
+                "/".join([self.template_path, 'get_parent.sql']),
+                tid=kwargs['tid']
+            )
             status, rset = self.conn.execute_2darray(SQL)
             if not status:
                 return internal_server_error(errormsg=rset)
@@ -260,8 +285,9 @@ class IndexesView(PGChildNodeView):
         """
         res = [{'label': '', 'value': ''}]
         try:
-            SQL = render_template("/".join([self.template_path,
-                                            'get_collations.sql']))
+            SQL = render_template(
+                "/".join([self.template_path, 'get_collations.sql'])
+            )
             status, rset = self.conn.execute_2darray(SQL)
             if not status:
                 return internal_server_error(errormsg=res)
@@ -287,8 +313,7 @@ class IndexesView(PGChildNodeView):
         """
         res = [{'label': '', 'value': ''}]
         try:
-            SQL = render_template("/".join([self.template_path,
-                                            'get_am.sql']))
+            SQL = render_template("/".join([self.template_path, 'get_am.sql']))
             status, rset = self.conn.execute_2darray(SQL)
             if not status:
                 return internal_server_error(errormsg=res)
@@ -315,17 +340,17 @@ class IndexesView(PGChildNodeView):
         res = dict()
         try:
             # Fetching all the access methods
-            SQL = render_template("/".join([self.template_path,
-                                            'get_am.sql']))
+            SQL = render_template("/".join([self.template_path, 'get_am.sql']))
             status, rset = self.conn.execute_2darray(SQL)
             if not status:
                 return internal_server_error(errormsg=res)
 
             for row in rset['rows']:
                 # Fetching all the op_classes for each access method
-                SQL = render_template("/".join([self.template_path,
-                                                'get_op_class.sql']),
-                                      oid=row['oid'])
+                SQL = render_template(
+                    "/".join([self.template_path, 'get_op_class.sql']),
+                    oid=row['oid']
+                )
                 status, result = self.conn.execute_2darray(SQL)
                 if not status:
                     return internal_server_error(errormsg=res)
@@ -350,7 +375,8 @@ class IndexesView(PGChildNodeView):
     @check_precondition
     def list(self, gid, sid, did, scid, tid):
         """
-        This function is used to list all the schema nodes within that collection.
+        This function is used to list all the schema nodes within that
+        collection.
 
         Args:
             gid: Server group ID
@@ -363,8 +389,9 @@ class IndexesView(PGChildNodeView):
             JSON of available schema nodes
         """
 
-        SQL = render_template("/".join([self.template_path,
-                                        'nodes.sql']), tid=tid)
+        SQL = render_template(
+            "/".join([self.template_path, 'nodes.sql']), tid=tid
+        )
         status, res = self.conn.execute_dict(SQL)
 
         if not status:
@@ -377,8 +404,8 @@ class IndexesView(PGChildNodeView):
     @check_precondition
     def node(self, gid, sid, did, scid, tid, idx):
         """
-        This function will used to create all the child node within that collection.
-        Here it will create all the schema node.
+        This function will used to create all the child node within that
+        collection. Here it will create all the schema node.
 
         Args:
             gid: Server Group ID
@@ -391,10 +418,10 @@ class IndexesView(PGChildNodeView):
         Returns:
             JSON of available schema child nodes
         """
-        SQL = render_template("/".join([self.template_path,
-                                        'nodes.sql']),
-                              tid=tid,
-                              idx=idx)
+        SQL = render_template(
+            "/".join([self.template_path, 'nodes.sql']),
+            tid=tid, idx=idx
+        )
         status, rset = self.conn.execute_2darray(SQL)
         if not status:
             return internal_server_error(errormsg=rset)
@@ -403,11 +430,11 @@ class IndexesView(PGChildNodeView):
             return gone(gettext("""Could not find the index in the table."""))
 
         res = self.blueprint.generate_browser_node(
-                rset['rows'][0]['oid'],
-                tid,
-                rset['rows'][0]['name'],
-                icon="icon-index"
-            )
+            rset['rows'][0]['oid'],
+            tid,
+            rset['rows'][0]['name'],
+            icon="icon-index"
+        )
 
         return make_json_response(
             data=res,
@@ -417,8 +444,8 @@ class IndexesView(PGChildNodeView):
     @check_precondition
     def nodes(self, gid, sid, did, scid, tid):
         """
-        This function will used to create all the child node within that collection.
-        Here it will create all the schema node.
+        This function will used to create all the child node within that
+        collection. Here it will create all the schema node.
 
         Args:
             gid: Server Group ID
@@ -431,8 +458,9 @@ class IndexesView(PGChildNodeView):
             JSON of available schema child nodes
         """
         res = []
-        SQL = render_template("/".join([self.template_path,
-                                        'nodes.sql']), tid=tid)
+        SQL = render_template(
+            "/".join([self.template_path, 'nodes.sql']), tid=tid
+        )
         status, rset = self.conn.execute_2darray(SQL)
         if not status:
             return internal_server_error(errormsg=rset)
@@ -451,7 +479,7 @@ class IndexesView(PGChildNodeView):
             status=200
         )
 
-    def _column_details(self, idx, data):
+    def _column_details(self, idx, data, mode='properties'):
         """
         This functional will fetch list of column details for index
 
@@ -463,8 +491,9 @@ class IndexesView(PGChildNodeView):
             Updated properties data with column details
         """
 
-        SQL = render_template("/".join([self.template_path,
-                                        'column_details.sql']), idx=idx)
+        SQL = render_template(
+            "/".join([self.template_path, 'column_details.sql']), idx=idx
+        )
         status, rset = self.conn.execute_2darray(SQL)
         if not status:
             return internal_server_error(errormsg=rset)
@@ -474,8 +503,10 @@ class IndexesView(PGChildNodeView):
         cols = []
         for row in rset['rows']:
             # We need all data as collection for ColumnsModel
+            # we will not strip down colname when using in SQL to display
             cols_data = {
-                'colname': row['attdef'].strip('"'),
+                'colname': row['attdef'] if mode == 'create' else
+                row['attdef'].strip('"'),
                 'collspcname': row['collnspname'],
                 'op_class': row['opcname'],
             }
@@ -497,10 +528,35 @@ class IndexesView(PGChildNodeView):
         # Push as collection
         data['columns'] = columns
         # Push as string
-        data['cols'] = ', '.join(cols)
+        data['columns_csv'] = ', '.join(cols)
 
         return data
 
+    def _include_details(self, idx, data, mode='properties'):
+        """
+        This functional will fetch list of include details for index
+        supported with Postgres 11+
+
+        Args:
+            idx: Index OID
+            data: Properties data
+
+        Returns:
+            Updated properties data with include details
+        """
+
+        SQL = render_template(
+            "/".join([self.template_path, 'include_details.sql']), idx=idx
+        )
+        status, rset = self.conn.execute_2darray(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=rset)
+
+        # Push as collection
+        data['include'] = [col['colname'] for col in rset['rows']]
+        return data
+
     @check_precondition
     def properties(self, gid, sid, did, scid, tid, idx):
         """
@@ -519,10 +575,10 @@ class IndexesView(PGChildNodeView):
             JSON of selected schema node
         """
 
-        SQL = render_template("/".join([self.template_path,
-                                        'properties.sql']),
-                              did=did, tid=tid, idx=idx,
-                              datlastsysoid=self.datlastsysoid)
+        SQL = render_template(
+            "/".join([self.template_path, 'properties.sql']),
+            did=did, tid=tid, idx=idx, datlastsysoid=self.datlastsysoid
+        )
 
         status, res = self.conn.execute_dict(SQL)
 
@@ -538,6 +594,10 @@ class IndexesView(PGChildNodeView):
         # Add column details for current index
         data = self._column_details(idx, data)
 
+        # Add Include details of the index
+        if self.manager.version >= 110000:
+            data = self._include_details(idx, data)
+
         return ajax_response(
             response=data,
             status=200
@@ -593,9 +653,10 @@ class IndexesView(PGChildNodeView):
         try:
             # Start transaction.
             self.conn.execute_scalar("BEGIN;")
-            SQL = render_template("/".join([self.template_path,
-                                            'create.sql']),
-                                  data=data, conn=self.conn, mode='create')
+            SQL = render_template(
+                "/".join([self.template_path, 'create.sql']),
+                data=data, conn=self.conn, mode='create'
+            )
             status, res = self.conn.execute_scalar(SQL)
             if not status:
                 # End transaction.
@@ -604,9 +665,10 @@ class IndexesView(PGChildNodeView):
 
             # If user chooses concurrent index then we cannot run it along
             # with other alter statements so we will separate alter index part
-            SQL = render_template("/".join([self.template_path,
-                                            'alter.sql']),
-                                  data=data, conn=self.conn)
+            SQL = render_template(
+                "/".join([self.template_path, 'alter.sql']),
+                data=data, conn=self.conn
+            )
             SQL = SQL.strip('\n').strip(' ')
             if SQL != '':
                 status, res = self.conn.execute_scalar(SQL)
@@ -616,9 +678,10 @@ class IndexesView(PGChildNodeView):
                     return internal_server_error(errormsg=res)
 
             # we need oid to to add object in tree at browser
-            SQL = render_template("/".join([self.template_path,
-                                            'get_oid.sql']),
-                                  tid=tid, data=data)
+            SQL = render_template(
+                "/".join([self.template_path, 'get_oid.sql']),
+                tid=tid, data=data
+            )
             status, idx = self.conn.execute_scalar(SQL)
             if not status:
                 # End transaction.
@@ -641,7 +704,7 @@ class IndexesView(PGChildNodeView):
             return internal_server_error(errormsg=str(e))
 
     @check_precondition
-    def delete(self, gid, sid, did, scid, tid, idx):
+    def delete(self, gid, sid, did, scid, tid, idx=None):
         """
         This function will updates existing the schema object
 
@@ -653,6 +716,13 @@ class IndexesView(PGChildNodeView):
            tid: Table ID
            idx: Index ID
         """
+        if idx is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [idx]}
+
         # Below will decide if it's simple drop or drop with cascade call
         if self.cmd == 'delete':
             # This is a cascade operation
@@ -661,44 +731,42 @@ class IndexesView(PGChildNodeView):
             cascade = False
 
         try:
-            # We will first fetch the index name for current request
-            # so that we create template for dropping index
-            SQL = render_template("/".join([self.template_path,
-                                            'properties.sql']),
-                                  did=did, tid=tid, idx=idx,
-                                  datlastsysoid=self.datlastsysoid)
-
-            status, res = self.conn.execute_dict(SQL)
-            if not status:
-                return internal_server_error(errormsg=res)
-
-            if not res['rows']:
-                return make_json_response(
-                    success=0,
-                    errormsg=gettext(
-                        'Error: Object not found.'
-                    ),
-                    info=gettext(
-                        'The specified index could not be found.\n'
-                    )
+            for idx in data['ids']:
+                # We will first fetch the index name for current request
+                # so that we create template for dropping index
+                SQL = render_template(
+                    "/".join([self.template_path, 'properties.sql']),
+                    did=did, tid=tid, idx=idx, datlastsysoid=self.datlastsysoid
                 )
 
-            data = dict(res['rows'][0])
+                status, res = self.conn.execute_dict(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
-            SQL = render_template("/".join([self.template_path,
-                                            'delete.sql']),
-                                  data=data, conn=self.conn, cascade=cascade)
-            status, res = self.conn.execute_scalar(SQL)
-            if not status:
-                return internal_server_error(errormsg=res)
+                if not res['rows']:
+                    return make_json_response(
+                        success=0,
+                        errormsg=gettext(
+                            'Error: Object not found.'
+                        ),
+                        info=gettext(
+                            'The specified index could not be found.\n'
+                        )
+                    )
+
+                data = dict(res['rows'][0])
+
+                SQL = render_template(
+                    "/".join([self.template_path, 'delete.sql']),
+                    data=data, conn=self.conn, cascade=cascade
+                )
+                status, res = self.conn.execute_scalar(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
             return make_json_response(
                 success=1,
-                info=gettext("Index is dropped"),
-                data={
-                    'id': idx,
-                    'tid': tid
-                }
+                info=gettext("Index is dropped")
             )
 
         except Exception as e:
@@ -724,6 +792,8 @@ class IndexesView(PGChildNodeView):
         data['table'] = self.table
         try:
             SQL, name = self.get_sql(did, scid, tid, idx, data)
+            if not isinstance(SQL, (str, unicode)):
+                return SQL
             SQL = SQL.strip('\n').strip(' ')
             status, res = self.conn.execute_scalar(SQL)
             if not status:
@@ -766,6 +836,8 @@ class IndexesView(PGChildNodeView):
 
         try:
             sql, name = self.get_sql(did, scid, tid, idx, data, mode='create')
+            if not isinstance(sql, (str, unicode)):
+                return sql
             sql = sql.strip('\n').strip(' ')
             if sql == '':
                 sql = "--modified SQL"
@@ -781,14 +853,18 @@ class IndexesView(PGChildNodeView):
         This function will genrate sql from model data
         """
         if idx is not None:
-            SQL = render_template("/".join([self.template_path,
-                                            'properties.sql']),
-                                  did=did, tid=tid, idx=idx,
-                                  datlastsysoid=self.datlastsysoid)
+            SQL = render_template(
+                "/".join([self.template_path, 'properties.sql']),
+                did=did, tid=tid, idx=idx, datlastsysoid=self.datlastsysoid
+            )
 
             status, res = self.conn.execute_dict(SQL)
             if not status:
                 return internal_server_error(errormsg=res)
+            if len(res['rows']) == 0:
+                return gone(
+                    gettext("""Could not find the index in the table.""")
+                )
 
             old_data = dict(res['rows'][0])
 
@@ -818,11 +894,15 @@ class IndexesView(PGChildNodeView):
                     return gettext('-- definition incomplete')
 
             # If the request for new object which do not have did
-            SQL = render_template("/".join([self.template_path, 'create.sql']),
-                                  data=data, conn=self.conn, mode=mode)
+            SQL = render_template(
+                "/".join([self.template_path, 'create.sql']),
+                data=data, conn=self.conn, mode=mode
+            )
             SQL += "\n"
-            SQL += render_template("/".join([self.template_path, 'alter.sql']),
-                                   data=data, conn=self.conn)
+            SQL += render_template(
+                "/".join([self.template_path, 'alter.sql']),
+                data=data, conn=self.conn
+            )
 
         return SQL, data['name'] if 'name' in data else old_data['name']
 
@@ -840,14 +920,16 @@ class IndexesView(PGChildNodeView):
            idx: Index ID
         """
 
-        SQL = render_template("/".join([self.template_path,
-                                        'properties.sql']),
-                              did=did, tid=tid, idx=idx,
-                              datlastsysoid=self.datlastsysoid)
+        SQL = render_template(
+            "/".join([self.template_path, 'properties.sql']),
+            did=did, tid=tid, idx=idx, datlastsysoid=self.datlastsysoid
+        )
 
         status, res = self.conn.execute_dict(SQL)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(gettext("""Could not find the index in the table."""))
 
         data = dict(res['rows'][0])
         # Adding parent into data dict, will be using it while creating sql
@@ -855,15 +937,21 @@ class IndexesView(PGChildNodeView):
         data['table'] = self.table
 
         # Add column details for current index
-        data = self._column_details(idx, data)
+        data = self._column_details(idx, data, 'create')
+
+        # Add Include details of the index
+        if self.manager.version >= 110000:
+            data = self._include_details(idx, data, 'create')
 
         SQL, name = self.get_sql(did, scid, tid, None, data)
-
+        if not isinstance(SQL, (str, unicode)):
+            return SQL
         sql_header = u"-- Index: {0}\n\n-- ".format(data['name'])
 
-        sql_header += render_template("/".join([self.template_path,
-                                                'delete.sql']),
-                                      data=data, conn=self.conn)
+        sql_header += render_template(
+            "/".join([self.template_path, 'delete.sql']),
+            data=data, conn=self.conn
+        )
 
         SQL = sql_header + '\n\n' + SQL
 
@@ -948,13 +1036,18 @@ class IndexesView(PGChildNodeView):
 
             if is_pgstattuple:
                 # Fetch index details only if extended stats available
-                SQL = render_template("/".join([self.template_path,
-                                                'properties.sql']),
-                                      did=did, tid=tid, idx=idx,
-                                      datlastsysoid=self.datlastsysoid)
+                SQL = render_template(
+                    "/".join([self.template_path, 'properties.sql']),
+                    did=did, tid=tid, idx=idx,
+                    datlastsysoid=self.datlastsysoid
+                )
                 status, res = self.conn.execute_dict(SQL)
                 if not status:
                     return internal_server_error(errormsg=res)
+                if len(res['rows']) == 0:
+                    return gone(
+                        gettext("""Could not find the index in the table.""")
+                    )
 
                 data = dict(res['rows'][0])
                 index = data['name']
