@@ -31,7 +31,7 @@ define('pgadmin.node.table', [
         columns: ['name', 'relowner', 'is_partitioned', 'description'],
         hasStatistics: true,
         statsPrettifyFields: [gettext('Size'), gettext('Indexes size'), gettext('Table size'),
-          gettext('Toast table size'), gettext('Tuple length'),
+          gettext('TOAST table size'), gettext('Tuple length'),
           gettext('Dead tuple length'), gettext('Free space')],
         canDrop: SchemaChildTreeNode.isTreeItemOfChildOfSchema,
         canDropCascade: SchemaChildTreeNode.isTreeItemOfChildOfSchema,
@@ -47,7 +47,7 @@ define('pgadmin.node.table', [
       hasDepends: true,
       hasStatistics: true,
       statsPrettifyFields: [gettext('Size'), gettext('Indexes size'), gettext('Table size'),
-        gettext('Toast table size'), gettext('Tuple length'),
+        gettext('TOAST table size'), gettext('Tuple length'),
         gettext('Dead tuple length'), gettext('Free space')],
       sqlAlterHelp: 'sql-altertable.html',
       sqlCreateHelp: 'sql-createtable.html',
@@ -175,25 +175,25 @@ define('pgadmin.node.table', [
                   data: params,
                   dataType: 'json',
                 })
-                .done(function(res) {
-                  if (res.success == 1) {
-                    Alertify.success(res.info);
-                    t.removeIcon(i);
-                    data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
-                    t.addIcon(i, {icon: data.icon});
+                  .done(function(res) {
+                    if (res.success == 1) {
+                      Alertify.success(res.info);
+                      t.removeIcon(i);
+                      data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
+                      t.addIcon(i, {icon: data.icon});
+                      t.unload(i);
+                      t.setInode(i);
+                      t.deselect(i);
+                      // Fetch updated data from server
+                      setTimeout(function() {
+                        t.select(i);
+                      }, 10);
+                    }
+                  })
+                  .fail(function(xhr, status, error) {
+                    Alertify.pgRespErrorNotify(xhr, error);
                     t.unload(i);
-                    t.setInode(i);
-                    t.deselect(i);
-                    // Fetch updated data from server
-                    setTimeout(function() {
-                      t.select(i);
-                    }, 10);
-                  }
-                })
-                .fail(function(xhr, status, error) {
-                  Alertify.pgRespErrorNotify(xhr, error);
-                  t.unload(i);
-                });
+                  });
               }
             }, function() {}
           );
@@ -218,25 +218,25 @@ define('pgadmin.node.table', [
                   url: obj.generate_url(i, 'reset' , d, true),
                   type:'DELETE',
                 })
-                .done(function(res) {
-                  if (res.success == 1) {
-                    Alertify.success(res.info);
-                    t.removeIcon(i);
-                    data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
-                    t.addIcon(i, {icon: data.icon});
+                  .done(function(res) {
+                    if (res.success == 1) {
+                      Alertify.success(res.info);
+                      t.removeIcon(i);
+                      data.icon = data.is_partitioned ? 'icon-partition': 'icon-table';
+                      t.addIcon(i, {icon: data.icon});
+                      t.unload(i);
+                      t.setInode(i);
+                      t.deselect(i);
+                      // Fetch updated data from server
+                      setTimeout(function() {
+                        t.select(i);
+                      }, 10);
+                    }
+                  })
+                  .fail(function(xhr, status, error) {
+                    Alertify.pgRespErrorNotify(xhr, error);
                     t.unload(i);
-                    t.setInode(i);
-                    t.deselect(i);
-                    // Fetch updated data from server
-                    setTimeout(function() {
-                      t.select(i);
-                    }, 10);
-                  }
-                })
-                .fail(function(xhr, status, error) {
-                  Alertify.pgRespErrorNotify(xhr, error);
-                  t.unload(i);
-                });
+                  });
               }
             },
             function() {}
@@ -256,20 +256,20 @@ define('pgadmin.node.table', [
             url: obj.generate_url(i, 'count_rows' , d, true),
             type:'GET',
           })
-          .done(function(res) {
-            Alertify.success(res.info);
-            d.rows_cnt = res.data.total_rows;
-            t.unload(i);
-            t.setInode(i);
-            t.deselect(i);
-            setTimeout(function() {
-              t.select(i);
-            }, 10);
-          })
-          .fail(function(xhr, status, error) {
-            Alertify.pgRespErrorNotify(xhr, error);
-            t.unload(i);
-          });
+            .done(function(res) {
+              Alertify.success(res.info);
+              d.rows_cnt = res.data.total_rows;
+              t.unload(i);
+              t.setInode(i);
+              t.deselect(i);
+              setTimeout(function() {
+                t.select(i);
+              }, 10);
+            })
+            .fail(function(xhr, status, error) {
+              Alertify.pgRespErrorNotify(xhr, error);
+              t.unload(i);
+            });
         },
       },
       model: pgBrowser.Node.Model.extend({
@@ -309,8 +309,8 @@ define('pgadmin.node.table', [
         initialize: function(attrs, args) {
           if (_.size(attrs) === 0) {
             var userInfo = pgBrowser.serverInfo[
-              args.node_info.server._id
-            ].user,
+                args.node_info.server._id
+              ].user,
               schemaInfo = args.node_info.schema;
 
             this.set({
@@ -358,7 +358,7 @@ define('pgadmin.node.table', [
             return false;
           },
         },{
-          id: 'is_partitioned', label:gettext('Partitioned Table?'), cell: 'switch',
+          id: 'is_partitioned', label:gettext('Partitioned table?'), cell: 'switch',
           type: 'switch', mode: ['properties', 'create', 'edit'],
           visible: function(m) {
             if(!_.isUndefined(m.node_info) && !_.isUndefined(m.node_info.server)
@@ -595,7 +595,7 @@ define('pgadmin.node.table', [
           type: 'nested', control: 'tab', group: gettext('Constraints'),
           mode: ['edit', 'create'],
           schema: [{
-            id: 'primary_key', label: gettext('Primary key'),
+            id: 'primary_key', label: '',
             model: pgBrowser.Nodes['primary_key'].model,
             subnode: pgBrowser.Nodes['primary_key'].model,
             editable: false, type: 'collection',
@@ -625,7 +625,7 @@ define('pgadmin.node.table', [
                   _.some(columns.pluck('name')));
             },
           },{
-            id: 'foreign_key', label: gettext('Foreign key'),
+            id: 'foreign_key', label: '',
             model: pgBrowser.Nodes['foreign_key'].model,
             subnode: pgBrowser.Nodes['foreign_key'].model,
             editable: false, type: 'collection',
@@ -652,7 +652,7 @@ define('pgadmin.node.table', [
               return _.some(columns.pluck('name'));
             },
           },{
-            id: 'check_constraint', label: gettext('Check constraint'),
+            id: 'check_constraint', label: '',
             model: pgBrowser.Nodes['check_constraint'].model,
             subnode: pgBrowser.Nodes['check_constraint'].model,
             editable: false, type: 'collection',
@@ -662,7 +662,7 @@ define('pgadmin.node.table', [
             canAdd: true,
             columns : ['name', 'consrc'],
           },{
-            id: 'unique_constraint', label: gettext('Unique Constraint'),
+            id: 'unique_constraint', label: '',
             model: pgBrowser.Nodes['unique_constraint'].model,
             subnode: pgBrowser.Nodes['unique_constraint'].model,
             editable: false, type: 'collection',
@@ -688,7 +688,7 @@ define('pgadmin.node.table', [
               return _.some(columns.pluck('name'));
             },
           },{
-            id: 'exclude_constraint', label: gettext('Exclude constraint'),
+            id: 'exclude_constraint', label: '',
             model: pgBrowser.Nodes['exclusion_constraint'].model,
             subnode: pgBrowser.Nodes['exclusion_constraint'].model,
             editable: false, type: 'collection',
@@ -716,7 +716,7 @@ define('pgadmin.node.table', [
         },{
           id: 'typname', label: gettext('Of type'), type: 'text',
           mode: ['properties', 'create', 'edit'],
-          disabled: 'checkOfType', url: 'get_oftype', group: 'advanced',
+          disabled: 'checkOfType', url: 'get_oftype', group: gettext('advanced'),
           deps: ['coll_inherits'], transform: function(data, cell) {
             var control = cell || this,
               m = control.model;
@@ -739,22 +739,22 @@ define('pgadmin.node.table', [
                   msg = gettext('Changing \'Of type\' will remove column definitions.');
 
                 Alertify.confirm(
-                    title, msg, function () {
-                      // User clicks Ok, lets clear columns collection
-                      column_collection.remove(
-                        column_collection.filter(function() { return true; })
-                      );
-                    },
-                    function() {
-                      setTimeout(function() {
-                        self.model.set('typname', null);
-                      }, 10);
-                    }
-                  );
+                  title, msg, function () {
+                    // User clicks Ok, lets clear columns collection
+                    column_collection.remove(
+                      column_collection.filter(function() { return true; })
+                    );
+                  },
+                  function() {
+                    setTimeout(function() {
+                      self.model.set('typname', null);
+                    }, 10);
+                  }
+                );
               } else if (!_.isUndefined(tbl_name) && tbl_name === '') {
                 column_collection.remove(
-                    column_collection.filter(function() { return true; })
-                  );
+                  column_collection.filter(function() { return true; })
+                );
               }
 
               // Run Ajax now to fetch columns
@@ -769,27 +769,27 @@ define('pgadmin.node.table', [
         },{
           id: 'fillfactor', label: gettext('Fill factor'), type: 'int',
           mode: ['create', 'edit'], min: 10, max: 100,
-          disabled: 'inSchema',group: 'advanced',
+          disabled: 'inSchema', group: gettext('advanced'),
         },{
           id: 'relhasoids', label: gettext('Has OIDs?'), cell: 'switch',
           type: 'switch', mode: ['properties', 'create', 'edit'],
-          disabled: 'inSchema', group: 'advanced',
+          disabled: 'inSchema', group: gettext('advanced'),
         },{
           id: 'relpersistence', label: gettext('Unlogged?'), cell: 'switch',
           type: 'switch', mode: ['properties', 'create', 'edit'],
           disabled: 'inSchemaWithModelCheck',
-          group: 'advanced',
+          group: gettext('advanced'),
         },{
           id: 'conname', label: gettext('Primary key'), cell: 'string',
-          type: 'text', mode: ['properties'], group: 'advanced',
+          type: 'text', mode: ['properties'], group: gettext('advanced'),
           disabled: 'inSchema',
         },{
           id: 'reltuples', label: gettext('Rows (estimated)'), cell: 'string',
-          type: 'text', mode: ['properties'], group: 'advanced',
+          type: 'text', mode: ['properties'], group: gettext('advanced'),
           disabled: 'inSchema',
         },{
           id: 'rows_cnt', label: gettext('Rows (counted)'), cell: 'string',
-          type: 'text', mode: ['properties'], group: 'advanced',
+          type: 'text', mode: ['properties'], group: gettext('advanced'),
           disabled: 'inSchema', control: Backform.InputControl.extend({
             formatter: {
               fromRaw: function (rawData) {
@@ -811,7 +811,7 @@ define('pgadmin.node.table', [
           }),
         },{
           id: 'relhassubclass', label: gettext('Inherits tables?'), cell: 'switch',
-          type: 'switch', mode: ['properties'], group: 'advanced',
+          type: 'switch', mode: ['properties'], group: gettext('advanced'),
           disabled: 'inSchema',
         },{
           id: 'is_sys_table', label: gettext('System table?'), cell: 'switch',
@@ -819,7 +819,7 @@ define('pgadmin.node.table', [
           disabled: 'inSchema',
         },{
           type: 'nested', control: 'fieldset', label: gettext('Like'),
-          group: 'advanced',
+          group: gettext('advanced'),
           schema:[{
             id: 'like_relation', label: gettext('Relation'),
             type: 'text', mode: ['create', 'edit'], deps: ['typname'],
@@ -903,7 +903,7 @@ define('pgadmin.node.table', [
             if (m.get('partition_type') && m.get('partition_type') == 'list')
               max_row_count = 1;
 
-              /* If columns are not specified by the user then it may be
+            /* If columns are not specified by the user then it may be
                * possible that he/she selected 'OF TYPE', so we should check
                * for that as well.
                */
@@ -1011,19 +1011,19 @@ define('pgadmin.node.table', [
                   type: 'GET',
                   async: false,
                 })
-                .done(function(res) {
-                  if (res.success == 1) {
-                    self.model.table_options = res.data;
-                  }
-                  else {
-                    Alertify.alert(
-                      gettext('Error fetching tables to be attached'), res.data.result
-                    );
-                  }
-                })
-                .fail(function(xhr, status, error) {
-                  Alertify.pgRespErrorNotify(xhr, error);
-                });
+                  .done(function(res) {
+                    if (res.success == 1) {
+                      self.model.table_options = res.data;
+                    }
+                    else {
+                      Alertify.alert(
+                        gettext('Error fetching tables to be attached'), res.data.result
+                      );
+                    }
+                  })
+                  .fail(function(xhr, status, error) {
+                    Alertify.pgRespErrorNotify(xhr, error);
+                  });
               }
             },
           }
@@ -1081,7 +1081,7 @@ define('pgadmin.node.table', [
         },{
           // Here - we will create tab control for storage parameters
           // (auto vacuum).
-          type: 'nested', control: 'tab', group: gettext('Parameter'),
+          type: 'nested', control: 'tab', group: gettext('Parameters'),
           mode: ['edit', 'create'], deps: ['is_partitioned'],
           schema: Backform.VacuumSettingsSchema,
         },{
@@ -1291,12 +1291,12 @@ define('pgadmin.node.table', [
             url: full_url,
             data: arg,
           })
-          .done(function(res) {
-            data = cache_node.cache(url, node_info, cache_level, res.data);
-          })
-          .fail(function() {
-            m.trigger('pgadmin:view:fetch:error', m, self.field);
-          });
+            .done(function(res) {
+              data = cache_node.cache(url, node_info, cache_level, res.data);
+            })
+            .fail(function() {
+              m.trigger('pgadmin:view:fetch:error', m, self.field);
+            });
           m.trigger('pgadmin:view:fetched', m, self.field);
           data = (data && data.data) || [];
           return data;
