@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -11,20 +11,20 @@
 
 from functools import wraps
 
-import pgadmin.browser.server_groups.servers.databases as databases
 import simplejson as json
 from flask import render_template, request, jsonify, current_app
-from flask_babel import gettext
+from flask_babelex import gettext
+
+import pgadmin.browser.server_groups.servers.databases as databases
+from config import PG_DEFAULT_DRIVER
 from pgadmin.browser.server_groups.servers.databases.schemas.utils import \
     SchemaChildModule, parse_rule_definition, VacuumSettings
+from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db, \
+    parse_priv_to_db
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
-    make_response as ajax_response, bad_request
+    make_response as ajax_response, gone
 from pgadmin.utils.driver import get_driver
-from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db,\
-    parse_priv_to_db
-from config import PG_DEFAULT_DRIVER
-from pgadmin.utils.ajax import gone
 
 """
     This module is responsible for generating two nodes
@@ -144,6 +144,7 @@ class MViewModule(ViewModule):
         super(MViewModule, self).__init__(*args, **kwargs)
         self.min_ver = 90300
         self.max_ver = None
+        self.min_gpdbver = 1000000000
 
 
 view_blueprint = ViewModule(__name__)
@@ -171,19 +172,25 @@ def check_precondition(f):
             kwargs['sid']
         )
         self.conn = self.manager.connection(did=kwargs['did'])
-        self.datlastsysoid = self.manager.db_info[
-            kwargs['did']
-        ]['datlastsysoid'] if self.manager.db_info is not None and \
-            kwargs['did'] in self.manager.db_info else 0
+        self.datlastsysoid = 0
+        if (
+            self.manager.db_info is not None and
+            kwargs['did'] in self.manager.db_info
+        ):
+            self.datlastsysoid = self.manager.db_info[kwargs['did']][
+                'datlastsysoid']
 
         # Set template path for sql scripts
-        self.template_path = self.template_initial + '/' + (
-            self.ppas_template_path(self.manager.version)
-            if self.manager.server_type == 'ppas' else
-            self.pg_template_path(self.manager.version)
-        )
+        if self.manager.server_type == 'gpdb':
+            _temp = self.gpdb_template_path(self.manager.version)
+        elif self.manager.server_type == 'ppas':
+            _temp = self.ppas_template_path(self.manager.version)
+        else:
+            _temp = self.pg_template_path(self.manager.version)
+        self.template_path = self.template_initial + '/' + _temp
 
-        self.column_template_path = 'column/sql/#{0}#'.format(self.manager.version)
+        self.column_template_path = 'column/sql/#{0}#'.format(
+            self.manager.version)
 
         return f(*args, **kwargs)
 
@@ -263,12 +270,12 @@ class ViewNode(PGChildNodeView, VacuumSettings):
     operations = dict({
         'obj': [
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
-            {'get': 'list', 'post': 'create'}
+            {'get': 'list', 'post': 'create', 'delete': 'delete'}
         ],
         'children': [{
             'get': 'children'
         }],
-        'delete': [{'delete': 'delete'}],
+        'delete': [{'delete': 'delete'}, {'delete': 'delete'}],
         'nodes': [{'get': 'node'}, {'get': 'nodes'}],
         'sql': [{'get': 'sql'}],
         'msql': [{'get': 'msql'}, {'get': 'msql'}],
@@ -314,6 +321,13 @@ class ViewNode(PGChildNodeView, VacuumSettings):
         """
         return 'pg/#{0}#'.format(ver)
 
+    @staticmethod
+    def gpdb_template_path(ver):
+        """
+        Returns the template path for GreenPlum servers.
+        """
+        return '#gpdb#{0}#'.format(ver)
+
     @check_precondition
     def list(self, gid, sid, did, scid):
         """
@@ -346,11 +360,12 @@ class ViewNode(PGChildNodeView, VacuumSettings):
             return gone(gettext("""Could not find the view."""))
 
         res = self.blueprint.generate_browser_node(
-                rset['rows'][0]['oid'],
-                scid,
-                rset['rows'][0]['name'],
-                icon="icon-view"
-            )
+            rset['rows'][0]['oid'],
+            scid,
+            rset['rows'][0]['name'],
+            icon="icon-view" if self.node_type == 'view'
+            else "icon-mview"
+        )
 
         return make_json_response(
             data=res,
@@ -375,7 +390,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
                     row['oid'],
                     scid,
                     row['name'],
-                    icon="icon-view"
+                    icon="icon-view" if self.node_type == 'view'
+                    else "icon-mview"
                 ))
 
         return make_json_response(
@@ -490,7 +506,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
                     view_id,
                     scid,
                     data['name'],
-                    icon="icon-view"
+                    icon="icon-view" if self.node_type == 'view'
+                    else "icon-mview"
                 )
             )
         except Exception as e:
@@ -506,9 +523,9 @@ class ViewNode(PGChildNodeView, VacuumSettings):
             request.data, encoding='utf-8'
         )
         try:
-            SQL, nameOrError = self.getSQL(gid, sid, did, data, vid)
+            SQL, name = self.getSQL(gid, sid, did, data, vid)
             if SQL is None:
-                return nameOrError
+                return name
             SQL = SQL.strip('\n').strip(' ')
             status, res = self.conn.execute_void(SQL)
             if not status:
@@ -535,7 +552,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
                     view_id,
                     scid,
                     new_view_name,
-                    icon="icon-view"
+                    icon="icon-view" if self.node_type == 'view'
+                    else "icon-mview"
                 )
             )
         except Exception as e:
@@ -543,60 +561,61 @@ class ViewNode(PGChildNodeView, VacuumSettings):
             return internal_server_error(errormsg=str(e))
 
     @check_precondition
-    def delete(self, gid, sid, did, scid, vid):
+    def delete(self, gid, sid, did, scid, vid=None):
         """
         This function will drop a view object
         """
+        if vid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [vid]}
 
         # Below will decide if it's simple drop or drop with cascade call
         cascade = True if self.cmd == 'delete' else False
 
         try:
-            # Get name for view from vid
-            SQL = render_template(
-                "/".join([
-                    self.template_path, 'sql/properties.sql'
-                ]),
-                did=did,
-                vid=vid,
-                datlastsysoid=self.datlastsysoid
-            )
-            status, res_data = self.conn.execute_dict(SQL)
-            if not status:
-                return internal_server_error(errormsg=res_data)
-
-            if not res_data['rows']:
-                return make_json_response(
-                    success=0,
-                    errormsg=gettext(
-                        'Error: Object not found.'
-                    ),
-                    info=gettext(
-                        'The specified view could not be found.\n'
-                    )
+            for vid in data['ids']:
+                # Get name for view from vid
+                SQL = render_template(
+                    "/".join([
+                        self.template_path, 'sql/properties.sql'
+                    ]),
+                    did=did,
+                    vid=vid,
+                    datlastsysoid=self.datlastsysoid
                 )
+                status, res_data = self.conn.execute_dict(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res_data)
 
-            # drop view
-            SQL = render_template(
-                "/".join([
-                    self.template_path, 'sql/delete.sql'
-                ]),
-                nspname=res_data['rows'][0]['schema'],
-                name=res_data['rows'][0]['name'], cascade=cascade
-            )
-            status, res = self.conn.execute_scalar(SQL)
-            if not status:
-                return internal_server_error(errormsg=res)
+                if not res_data['rows']:
+                    return make_json_response(
+                        success=0,
+                        errormsg=gettext(
+                            'Error: Object not found.'
+                        ),
+                        info=gettext(
+                            'The specified view could not be found.\n'
+                        )
+                    )
+
+                # drop view
+                SQL = render_template(
+                    "/".join([
+                        self.template_path, 'sql/delete.sql'
+                    ]),
+                    nspname=res_data['rows'][0]['schema'],
+                    name=res_data['rows'][0]['name'], cascade=cascade
+                )
+                status, res = self.conn.execute_scalar(SQL)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
             return make_json_response(
                 success=1,
-                info=gettext("View dropped"),
-                data={
-                    'id': vid,
-                    'sid': sid,
-                    'gid': gid,
-                    'did': did
-                }
+                info=gettext("View dropped")
             )
 
         except Exception as e:
@@ -659,7 +678,10 @@ class ViewNode(PGChildNodeView, VacuumSettings):
             status, res = self.conn.execute_dict(SQL)
             if not status:
                 return None, internal_server_error(errormsg=res)
-
+            if len(res['rows']) == 0:
+                return None, gone(
+                    gettext("Could not find the view on the server.")
+                )
             old_data = res['rows'][0]
 
             if 'name' not in data:
@@ -751,7 +773,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
 
         self.index_temp_path = 'index'
         SQL = render_template("/".join([self.index_temp_path,
-                                        'sql/#{0}#/column_details.sql'.format(self.manager.version)]), idx=idx)
+                                        'sql/#{0}#/column_details.sql'.format(
+                                            self.manager.version)]), idx=idx)
         status, rset = self.conn.execute_2darray(SQL)
         if not status:
             return internal_server_error(errormsg=rset)
@@ -764,7 +787,7 @@ class ViewNode(PGChildNodeView, VacuumSettings):
 
             # We need all data as collection for ColumnsModel
             cols_data = {
-                'colname': row['attdef'].strip('"'),
+                'colname': row['attdef'],
                 'collspcname': row['collnspname'],
                 'op_class': row['opcname'],
             }
@@ -857,6 +880,9 @@ class ViewNode(PGChildNodeView, VacuumSettings):
         generate their sql and render
         into sql tab
         """
+        if self.manager.server_type == 'gpdb':
+            return ''
+
         from pgadmin.browser.server_groups.servers.databases.schemas.utils \
             import trigger_definition
 
@@ -865,7 +891,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
 
         SQL_data = ''
         SQL = render_template("/".join(
-            [self.trigger_temp_path, 'sql/#{0}#/properties.sql'.format(self.manager.version)]),
+            [self.trigger_temp_path,
+             'sql/#{0}#/properties.sql'.format(self.manager.version)]),
             tid=vid)
 
         status, data = self.conn.execute_dict(SQL)
@@ -874,7 +901,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
 
         for trigger in data['rows']:
             SQL = render_template("/".join(
-                [self.trigger_temp_path, 'sql/#{0}#/properties.sql'.format(self.manager.version)]),
+                [self.trigger_temp_path,
+                 'sql/#{0}#/properties.sql'.format(self.manager.version)]),
                 tid=vid,
                 trid=trigger['oid']
             )
@@ -894,23 +922,41 @@ class ViewNode(PGChildNodeView, VacuumSettings):
                     trigger['oid'], columns)
             res_rows = trigger_definition(res_rows)
 
-            res_rows['schema'] = res_rows['nspname']
-
             # It should be relname and not table, but in create.sql
             # (which is referred from many places) we have used
             # data.table and not data.relname so compatibility add new key as
             # table in res_rows.
             res_rows['table'] = res_rows['relname']
+            res_rows['schema'] = self.view_schema
 
-            res_rows['tfunction'] = self.qtIdent(self.conn, res_rows['schema'], res_rows['tfunction'])
+            # Get trigger function with its schema name
+            SQL = render_template("/".join([
+                self.trigger_temp_path,
+                'sql/#{0}#/get_triggerfunctions.sql'.format(
+                    self.manager.version)]),
+                tgfoid=res_rows['tgfoid'],
+                show_system_objects=self.blueprint.show_system_objects)
+
+            status, result = self.conn.execute_dict(SQL)
+            if not status:
+                return internal_server_error(errormsg=result)
+
+            # Update the trigger function which we have fetched with schemaname
+            if (
+                'rows' in result and len(result['rows']) > 0 and
+                'tfunctions' in result['rows'][0]
+            ):
+                res_rows['tfunction'] = result['rows'][0]['tfunctions']
 
             # Format arguments
             if len(res_rows['custom_tgargs']) > 1:
-                formatted_args = ["{0}".format(arg) for arg in res_rows['custom_tgargs']]
+                formatted_args = ["{0}".format(arg) for arg in
+                                  res_rows['custom_tgargs']]
                 res_rows['tgargs'] = ', '.join(formatted_args)
 
             SQL = render_template("/".join(
-                [self.trigger_temp_path, 'sql/#{0}#/create.sql'.format(self.manager.version)]),
+                [self.trigger_temp_path,
+                 'sql/#{0}#/create.sql'.format(self.manager.version)]),
                 data=res_rows, display_comments=True)
             SQL_data += '\n'
             SQL_data += SQL
@@ -927,7 +973,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
         self.index_temp_path = 'index'
         SQL_data = ''
         SQL = render_template("/".join(
-            [self.index_temp_path, 'sql/#{0}#/properties.sql'.format(self.manager.version)]),
+            [self.index_temp_path,
+             'sql/#{0}#/properties.sql'.format(self.manager.version)]),
             did=did,
             tid=vid)
         status, data = self.conn.execute_dict(SQL)
@@ -937,7 +984,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
         for index in data['rows']:
             res = []
             SQL = render_template("/".join(
-                [self.index_temp_path, 'sql/#{0}#/properties.sql'.format(self.manager.version)]),
+                [self.index_temp_path,
+                 'sql/#{0}#/properties.sql'.format(self.manager.version)]),
                 idx=index['oid'],
                 did=did,
                 tid=vid
@@ -953,7 +1001,8 @@ class ViewNode(PGChildNodeView, VacuumSettings):
             data = self.get_index_column_details(index['oid'], data)
 
             SQL = render_template("/".join(
-                [self.index_temp_path, 'sql/#{0}#/create.sql'.format(self.manager.version)]),
+                [self.index_temp_path,
+                 'sql/#{0}#/create.sql'.format(self.manager.version)]),
                 data=data, display_comments=True)
             SQL_data += '\n'
             SQL_data += SQL
@@ -975,6 +1024,10 @@ class ViewNode(PGChildNodeView, VacuumSettings):
         status, res = self.conn.execute_dict(SQL)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(
+                gettext("Could not find the view on the server.")
+            )
 
         result = res['rows'][0]
         # sending result to formtter
@@ -982,6 +1035,7 @@ class ViewNode(PGChildNodeView, VacuumSettings):
 
         # merging formated result with main result again
         result.update(frmtd_reslt)
+        self.view_schema = result.get('schema')
 
         # Fetch all privileges for view
         SQL = render_template("/".join(
@@ -1113,12 +1167,16 @@ class ViewNode(PGChildNodeView, VacuumSettings):
             "/".join([
                 self.template_path, 'sql/properties.sql'
             ]),
-            scid=scid, vid=vid,
+            scid=scid, vid=vid, did=did,
             datlastsysoid=self.datlastsysoid
         )
         status, res = self.conn.execute_dict(SQL)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(
+                gettext("Could not find the view on the server.")
+            )
         data_view = res['rows'][0]
 
         SQL = render_template(
@@ -1170,12 +1228,17 @@ class ViewNode(PGChildNodeView, VacuumSettings):
             "/".join([
                 self.template_path, 'sql/properties.sql'
             ]),
-            scid=scid, vid=vid,
+            scid=scid, vid=vid, did=did,
             datlastsysoid=self.datlastsysoid
         )
         status, res = self.conn.execute_dict(SQL)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(
+                gettext("Could not find the view on the server.")
+            )
+
         data_view = res['rows'][0]
 
         SQL = render_template(
@@ -1292,6 +1355,12 @@ class MViewNode(ViewNode, VacuumSettings):
             status, res = self.conn.execute_dict(SQL)
             if not status:
                 return None, internal_server_error(errormsg=res)
+            if len(res['rows']) == 0:
+                return None, gone(
+                    gettext(
+                        "Could not find the materialized view on the server.")
+                )
+
             old_data = res['rows'][0]
 
             if 'name' not in data:
@@ -1314,18 +1383,26 @@ class MViewNode(ViewNode, VacuumSettings):
                                     data['vacuum_data']['reset'].append(item)
                             else:
                                 if (old_data[item['name']] is None or
-                                        (float(old_data[item['name']]) != float(item['value']))):
+                                    (float(old_data[item['name']]) != float(
+                                        item['value']))):
                                     data['vacuum_data']['changed'].append(item)
 
-            if ('autovacuum_enabled' in data and
-                        old_data['autovacuum_enabled'] is not None):
-                if (data['autovacuum_enabled'] !=
-                        old_data['autovacuum_enabled']):
+            if (
+                'autovacuum_enabled' in data and
+                old_data['autovacuum_enabled'] is not None
+            ):
+                if (
+                    data['autovacuum_enabled'] !=
+                    old_data['autovacuum_enabled']
+                ):
                     data['vacuum_data']['changed'].append(
                         {'name': 'autovacuum_enabled',
                          'value': data['autovacuum_enabled']})
-            elif ('autovacuum_enabled' in data and 'autovacuum_custom' in data and
-                          old_data['autovacuum_enabled'] is None and data['autovacuum_custom']):
+            elif (
+                'autovacuum_enabled' in data and
+                'autovacuum_custom' in data and
+                old_data['autovacuum_enabled'] is None and data[
+                    'autovacuum_custom']):
                 data['vacuum_data']['changed'].append(
                     {'name': 'autovacuum_enabled',
                      'value': data['autovacuum_enabled']})
@@ -1342,18 +1419,27 @@ class MViewNode(ViewNode, VacuumSettings):
                                     data['vacuum_data']['reset'].append(item)
                             else:
                                 if (old_data[toast_key] is None or
-                                        (float(old_data[toast_key]) != float(item['value']))):
+                                    (float(old_data[toast_key]) != float(
+                                        item['value']))):
                                     data['vacuum_data']['changed'].append(item)
 
-            if ('toast_autovacuum_enabled' in data and
-                        old_data['toast_autovacuum_enabled'] is not None):
-                if (data['toast_autovacuum_enabled'] !=
-                        old_data['toast_autovacuum_enabled']):
+            if (
+                'toast_autovacuum_enabled' in data and
+                old_data['toast_autovacuum_enabled'] is not None
+            ):
+                if (
+                    data['toast_autovacuum_enabled'] !=
+                    old_data['toast_autovacuum_enabled']
+                ):
                     data['vacuum_data']['changed'].append(
                         {'name': 'toast.autovacuum_enabled',
                          'value': data['toast_autovacuum_enabled']})
-            elif ('toast_autovacuum_enabled' in data and 'toast_autovacuum' in data and
-                          old_data['toast_autovacuum_enabled'] is None and data['toast_autovacuum']):
+            elif (
+                'toast_autovacuum_enabled' in data and
+                'toast_autovacuum' in data and
+                old_data['toast_autovacuum_enabled'] is None and
+                data['toast_autovacuum']
+            ):
                 data['vacuum_data']['changed'].append(
                     {'name': 'toast.autovacuum_enabled',
                      'value': data['toast_autovacuum_enabled']})
@@ -1429,14 +1515,17 @@ class MViewNode(ViewNode, VacuumSettings):
 
             # add vacuum_toast dict to vacuum_data only if
             # table & toast's custom autovacuum is enabled
-            data['vacuum_data'] = (vacuum_table if (
+            data['vacuum_data'] = []
+            if (
                 'autovacuum_custom' in data and
                 data['autovacuum_custom'] is True
-            ) else []) + (
-                                      vacuum_toast if (
-                                          'toast_autovacuum' in data and
-                                          data['toast_autovacuum'] is True
-                                      ) else [])
+            ):
+                data['vacuum_data'] = vacuum_table
+            if (
+                'toast_autovacuum' in data and
+                data['toast_autovacuum'] is True
+            ):
+                data['vacuum_data'] += vacuum_toast
 
             acls = []
             try:
@@ -1480,6 +1569,10 @@ class MViewNode(ViewNode, VacuumSettings):
         status, res = self.conn.execute_dict(SQL)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(
+                gettext("Could not find the materialized view on the server.")
+            )
 
         result = res['rows'][0]
 
@@ -1495,15 +1588,34 @@ class MViewNode(ViewNode, VacuumSettings):
 
         # merge vacuum lists into one
         vacuum_table = [item for item in result['vacuum_table']
-                        if 'value' in item.keys() and item['value'] is not None]
+                        if
+                        'value' in item.keys() and item['value'] is not None]
         vacuum_toast = [
             {'name': 'toast.' + item['name'], 'value': item['value']}
-            for item in result['vacuum_toast'] if 'value' in item.keys() and item['value'] is not None]
+            for item in result['vacuum_toast'] if
+            'value' in item.keys() and item['value'] is not None]
+
+        if 'autovacuum_custom' in result and result['autovacuum_custom']:
+            vacuum_table.append(
+                {
+                    'name': 'autovacuum_enabled',
+                    'value': str(result['autovacuum_enabled'])
+                }
+            )
+        if 'toast_autovacuum' in result and result['toast_autovacuum']:
+            vacuum_table.append(
+                {
+                    'name': 'toast.autovacuum_enabled',
+                    'value': str(result['toast_autovacuum_enabled'])
+                }
+            )
 
         # add vacuum_toast dict to vacuum_data only if
         # toast's autovacuum is enabled
-        if ('toast_autovacuum_enabled' in result and
-                    result['toast_autovacuum_enabled'] is True):
+        if (
+            'toast_autovacuum_enabled' in result and
+            result['toast_autovacuum_enabled'] is True
+        ):
             result['vacuum_data'] = vacuum_table + vacuum_toast
         else:
             result['vacuum_data'] = vacuum_table
