@@ -11,11 +11,14 @@ define('pgadmin.browser.node', [
   'sources/tree/pgadmin_tree_node', 'sources/url_for',
   'sources/gettext', 'jquery', 'underscore', 'underscore.string', 'sources/pgadmin',
   'pgadmin.browser.menu', 'backbone', 'pgadmin.alertifyjs', 'pgadmin.browser.datamodel',
-  'backform', 'sources/browser/generate_url', 'sources/utils', 'pgadmin.browser.utils',
-  'pgadmin.backform',
+  'backform', 'sources/browser/generate_url', 'pgadmin.help', 'sources/utils',
+  'pgadmin.browser.utils', 'pgadmin.backform',
 ], function(
   pgadminTreeNode, url_for,
-  gettext, $, _, S, pgAdmin, Menu, Backbone, Alertify, pgBrowser, Backform, generateUrl, commonUtils
+  gettext, $, _, S, pgAdmin,
+  Menu, Backbone, Alertify, pgBrowser,
+  Backform, generateUrl, help,
+  commonUtils
 ) {
 
   var wcDocker = window.wcDocker,
@@ -423,11 +426,11 @@ define('pgadmin.browser.node', [
                   xhr, error, message, item
                 );
                 if (!Alertify.pgHandleItemError(
-                    xhr, error, message, {
-                      item: item,
-                      info: info,
-                    }
-                  )) {
+                  xhr, error, message, {
+                    item: item,
+                    info: info,
+                  }
+                )) {
                   Alertify.pgNotifier(
                     error, xhr,
                     S(
@@ -484,6 +487,7 @@ define('pgadmin.browser.node', [
         showTitle: true,
         isCloseable: true,
         isPrivate: true,
+        isLayoutMember: false,
         elContainer: true,
         content: '<div class="obj_properties container-fluid"><div class="alert alert-info pg-panel-message">' + gettext('Please wait while we fetch information about the node from the server...') + '</div></div>',
         onCreate: function(myPanel, $container) {
@@ -738,10 +742,10 @@ define('pgadmin.browser.node', [
           title = S(gettext('DROP CASCADE %s?')).sprintf(obj.label).value();
 
           if (!(_.isFunction(obj.canDropCascade) ?
-              obj.canDropCascade.apply(obj, [d, i]) : obj.canDropCascade)) {
+            obj.canDropCascade.apply(obj, [d, i]) : obj.canDropCascade)) {
             Alertify.error(
               S(gettext('The %s "%s" cannot be dropped.'))
-              .sprintf(obj.label, d.label).value(),
+                .sprintf(obj.label, d.label).value(),
               10
             );
             return;
@@ -752,10 +756,10 @@ define('pgadmin.browser.node', [
           title = S(gettext('DROP %s?')).sprintf(obj.label).value();
 
           if (!(_.isFunction(obj.canDrop) ?
-              obj.canDrop.apply(obj, [d, i]) : obj.canDrop)) {
+            obj.canDrop.apply(obj, [d, i]) : obj.canDrop)) {
             Alertify.error(
               S(gettext('The %s "%s" cannot be dropped.'))
-              .sprintf(obj.label, d.label).value(),
+                .sprintf(obj.label, d.label).value(),
               10
             );
             return;
@@ -767,30 +771,30 @@ define('pgadmin.browser.node', [
               url: obj.generate_url(i, input.url, d, true),
               type: 'DELETE',
             })
-            .done(function(res) {
-              if (res.success == 0) {
-                pgBrowser.report_error(res.errormsg, res.info);
-              } else {
-                pgBrowser.removeTreeNode(i, true);
-              }
-              return true;
-            })
-            .fail(function(jqx) {
-              var msg = jqx.responseText;
-              /* Error from the server */
-              if (jqx.status == 417 || jqx.status == 410 || jqx.status == 500) {
-                try {
-                  var data = JSON.parse(jqx.responseText);
-                  msg = data.errormsg;
-                } catch (e) {
-                  console.warn(e.stack || e);
+              .done(function(res) {
+                if (res.success == 0) {
+                  pgBrowser.report_error(res.errormsg, res.info);
+                } else {
+                  pgBrowser.removeTreeNode(i, true);
                 }
-              }
-              pgBrowser.report_error(
-                S(gettext('Error dropping %s: "%s"'))
-                .sprintf(obj.label, objName)
-                .value(), msg);
-            });
+                return true;
+              })
+              .fail(function(jqx) {
+                var msg = jqx.responseText;
+                /* Error from the server */
+                if (jqx.status == 417 || jqx.status == 410 || jqx.status == 500) {
+                  try {
+                    var data = JSON.parse(jqx.responseText);
+                    msg = data.errormsg;
+                  } catch (e) {
+                    console.warn(e.stack || e);
+                  }
+                }
+                pgBrowser.report_error(
+                  S(gettext('Error dropping %s: "%s"'))
+                    .sprintf(obj.label, objName)
+                    .value(), msg);
+              });
           },
           null).show();
       },
@@ -913,7 +917,7 @@ define('pgadmin.browser.node', [
         }
 
         pgBrowser.Events.trigger('pgadmin:browser:tree:expand-from-previous-tree-state',
-         item);
+          item);
         pgBrowser.Node.callbacks.change_server_background(item, data);
       },
       // Callback called - when a node is selected in browser tree.
@@ -944,7 +948,7 @@ define('pgadmin.browser.node', [
         }
 
         pgBrowser.Events.trigger('pgadmin:browser:tree:update-tree-state',
-         item);
+          item);
         return true;
       },
       removed: function(item) {
@@ -1003,7 +1007,7 @@ define('pgadmin.browser.node', [
           auto_expand = pgBrowser.get_preference('browser', 'auto_expand_sole_children');
 
         pgBrowser.Events.trigger('pgadmin:browser:tree:update-tree-state',
-         item);
+          item);
 
         if (auto_expand && auto_expand.value == true && tree.children(item).length == 1) {
           // Automatically expand the child node, if a treeview node has only a single child.
@@ -1013,7 +1017,7 @@ define('pgadmin.browser.node', [
       },
       closed: function(item) {
         pgBrowser.Events.trigger('pgadmin:browser:tree:remove-from-tree-state',
-         item);
+          item);
       },
     },
     /**********************************************************************
@@ -1029,7 +1033,7 @@ define('pgadmin.browser.node', [
         j = panel.$container.find('.obj_properties').first(),
         view = j.data('obj-view'),
         content = $('<div tabindex="1"></div>')
-        .addClass('pg-prop-content col-12');
+          .addClass('pg-prop-content col-12');
 
       // Handle key press events for Cancel, save and help button
       var handleKeyDown = function(event, context) {
@@ -1041,12 +1045,12 @@ define('pgadmin.browser.node', [
           closePanel();
           break;
         case keyCode.ENTER:
-            // Return if event is fired from child element
+          // Return if event is fired from child element
           if (event.target !== context) return;
           if (view && view.model && view.model.sessChanged()) {
             var btn = $(event.target).closest('.obj_properties')
-                .find('.pg-prop-btn-group')
-                .find('button.btn-primary');
+              .find('.pg-prop-btn-group')
+              .find('button.btn-primary');
             onSave.call(this, view, btn);
           }
           break;
@@ -1218,26 +1222,20 @@ define('pgadmin.browser.node', [
             url = pgBrowser.utils.edbas_help_path;
           }
 
-          var major = Math.floor(server.version / 10000),
-            minor = Math.floor(server.version / 100) - (major * 100);
-
-          url = url.replace('$VERSION$', major + '.' + minor);
-          if (!S(url).endsWith('/')) {
-            url = url + '/';
-          }
+          var fullUrl = '';
           if (that.sqlCreateHelp == '' && that.sqlAlterHelp != '') {
-            url = url + that.sqlAlterHelp;
+            fullUrl = help.getHelpUrl(url, that.sqlAlterHelp, server.version);
           } else if (that.sqlCreateHelp != '' && that.sqlAlterHelp == '') {
-            url = url + that.sqlCreateHelp;
+            fullUrl = help.getHelpUrl(url, that.sqlCreateHelp, server.version);
           } else {
             if (view.model.isNew()) {
-              url = url + that.sqlCreateHelp;
+              fullUrl = help.getHelpUrl(url, that.sqlCreateHelp, server.version);
             } else {
-              url = url + that.sqlAlterHelp;
+              fullUrl = help.getHelpUrl(url, that.sqlAlterHelp, server.version);
             }
           }
 
-          window.open(url, 'postgres_help');
+          window.open(fullUrl, 'postgres_help');
         }.bind(panel),
 
         onDialogHelp = function() {
@@ -1364,8 +1362,8 @@ define('pgadmin.browser.node', [
 
             panel.icon(
               _.isFunction(that['node_image']) ?
-              (that['node_image']).apply(that, [data, view.model]) :
-              (that['node_image'] || ('icon-' + that.type))
+                (that['node_image']).apply(that, [data, view.model]) :
+                (that['node_image'] || ('icon-' + that.type))
             );
 
             // Create proper buttons
