@@ -65,13 +65,17 @@ def RegisterQueryToolPreferences(self):
     self.auto_commit = self.preference.register(
         'Options', 'auto_commit',
         gettext("Auto commit?"), 'boolean', True,
-        category_label=gettext('Options')
+        category_label=gettext('Options'),
+        help_str=gettext('Set auto commit on or off by default in new Query '
+                         'Tool tabs.')
     )
 
     self.auto_rollback = self.preference.register(
         'Options', 'auto_rollback',
         gettext("Auto rollback?"), 'boolean', False,
-        category_label=gettext('Options')
+        category_label=gettext('Options'),
+        help_str=gettext('Set auto rollback on or off by default in new Query '
+                         'Tool tabs.')
     )
 
     self.sql_font_size = self.preference.register(
@@ -571,3 +575,39 @@ def RegisterQueryToolPreferences(self):
         help_str=gettext('If set to True, Keywords will be displayed '
                          'in upper case for auto completion.')
     )
+
+    self.preference.register(
+        'keyboard_shortcuts',
+        'commit_transaction',
+        gettext('Commit'),
+        'keyboardshortcut',
+        {
+            'alt': False,
+            'shift': True,
+            'control': True,
+            'key': {
+                'key_code': 77,
+                'char': 'm'
+            }
+        },
+        category_label=gettext('Keyboard shortcuts'),
+        fields=shortcut_fields
+    )
+
+    self.preference.register(
+        'keyboard_shortcuts',
+        'rollback_transaction',
+        gettext('Rollback'),
+        'keyboardshortcut',
+        {
+            'alt': False,
+            'shift': True,
+            'control': True,
+            'key': {
+                'key_code': 82,
+                'char': 'r'
+            }
+        },
+        category_label=gettext('Keyboard shortcuts'),
+        fields=shortcut_fields
+    )
