@@ -10,7 +10,8 @@
 import time
 
 from selenium.common.exceptions import NoSuchElementException, \
-    WebDriverException, TimeoutException, NoSuchWindowException
+    WebDriverException, TimeoutException, NoSuchWindowException, \
+    StaleElementReferenceException
 from selenium.webdriver import ActionChains
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support import expected_conditions as EC
@@ -93,7 +94,6 @@ class PgadminPage:
         self.enable_menu_item(query_tool, 10)
 
         self.find_by_partial_link_text("Query Tool").click()
-        self.click_tab('Query -')
 
     def enable_menu_item(self, menu_item, wait_time):
         start_time = time.time()
@@ -110,11 +110,10 @@ class PgadminPage:
         else:
             assert False, "'Tools -> Query Tool' menu did not enable."
 
-    def close_query_tool(self, name="Query", prompt=True):
+    def close_query_tool(self, prompt=True):
         self.driver.switch_to.default_content()
         tab = self.find_by_xpath(
-            "//*[contains(@class,'wcPanelTab') and "
-            "contains(.,'" + name + "')]")
+            "//div[@class='wcPanelTab wcPanelTabActive']")
         ActionChains(self.driver).context_click(tab).perform()
         self.find_by_xpath(
             "//li[contains(@class, 'context-menu-item')]/span[contains(text(),"
@@ -149,18 +148,54 @@ class PgadminPage:
 
     def select_tree_item(self, tree_item_text):
         item = self.find_by_xpath(
-            "//*[@id='tree']//*[.='" + tree_item_text +
-            "' and @class='aciTreeItem']")
+            "//*[@id='tree']//*[contains(text(), '" + tree_item_text + "')]"
+            "/parent::span[@class='aciTreeItem']")
         self.driver.execute_script("arguments[0].scrollIntoView()", item)
         item.click()
 
+    def toggle_open_servers_group(self):
+        """This will open Servers group to display underlying nodes"""
+        self.wait_for_spinner_to_disappear()
+        server_group = self.find_by_xpath(
+            "//div[@id='tree']//span[@class='aciTreeItem']"
+            "/span[(@class='aciTreeText') and starts-with(text(),'Servers ') "
+            "or starts-with(text(), 'Servers')]")
+        ActionChains(self.driver).double_click(server_group).perform()
+
     def toggle_open_tree_item(self, tree_item_text):
-        item = self.find_by_xpath(
-            "//*[@id='tree']//*[.='" + tree_item_text +
-            "']/../*[@class='aciTreeButton']")
+        # 'sleep' here helps in cases where underlying nodes are auto opened.
+        # Otherwise, encountered situations where False value is returned
+        # even if the underlying node to be clicked was Opened.
+        time.sleep(.6)
+        item_with_text = self.find_by_xpath(
+            "//div[@id='tree']//span[@class='aciTreeItem']/span["
+            "(@class='aciTreeText') and text()='" + tree_item_text + "']")
 
-        self.driver.execute_script("arguments[0].scrollIntoView()", item)
-        item.click()
+        self.driver.execute_script("arguments[0].scrollIntoView()",
+                                   item_with_text)
+
+        if item_with_text.find_element_by_xpath(
+            ".//ancestor::*[@class='aciTreeLine']").get_attribute(
+                "aria-expanded") == 'false':
+            item = item_with_text.find_element_by_xpath(
+                ".//parent::*[@class='aciTreeItem']")
+            ActionChains(self.driver).double_click(item).perform()
+
+    def toggle_open_tables_node(self):
+        """The function will be used for opening Trees node only"""
+
+        # get the element which contains 'aria-expanded' info
+        tables_expansion_ele = self.find_by_xpath("//div[div[div[div[div[div"
+                                                  "[div[div[span[span["
+                                                  "(@class='aciTreeText') and "
+                                                  "text()='Tables']]]]]]]]]]")
+
+        if tables_expansion_ele.get_attribute('aria-expanded') == 'false':
+            # button element of the Tables node to open it
+            item_button = self.find_by_xpath(
+                "//div[span[span[(@class='aciTreeText') and text()"
+                "='Tables']]]/span[@class='aciTreeButton']")
+            ActionChains(self.driver).click(item_button).perform()
 
     def toggle_open_server(self, tree_item_text):
         def check_for_password_dialog_or_tree_open(driver):
@@ -224,38 +259,103 @@ class PgadminPage:
             "clicking the element not to throw an exception", click_succeeded
         )
 
-    def fill_input_by_field_name(self, field_name, field_content):
-        field = self.find_by_xpath("//input[@name='" + field_name + "']")
-        backspaces = [Keys.BACKSPACE] * len(field.get_attribute('value'))
+    def js_send_key(self, field, sele_key):
+        keycode = None
 
+        if sele_key in (Keys.RETURN, Keys.ENTER):
+            keycode = 13
+        elif sele_key == Keys.ARROW_DOWN:
+            keycode = 40
+
+        self.driver.execute_script(
+            "arguments[0].dispatchEvent(new KeyboardEvent('keydown', "
+            "{'keyCode':arguments[1], 'which':arguments[1]}));"
+            "arguments[0].dispatchEvent(new KeyboardEvent('keypress', "
+            "{'keyCode':arguments[1], 'which':arguments[1]}));"
+            "arguments[0].dispatchEvent(new KeyboardEvent('keyup', "
+            "{'keyCode':arguments[1], 'which':arguments[1]}));"
+            "arguments[0].dispatchEvent(new Event('input'));"
+            "arguments[0].dispatchEvent(new Event('change'));",
+            field, keycode)
+
+    def js_loose_focus(self, field):
+        self.driver.execute_script(
+            "arguments[0].dispatchEvent(new Event('blur'));", field)
+
+    def fill_input(self, field, field_content, input_keys=False,
+                   key_after_input=Keys.ARROW_DOWN):
         field.click()
-        field.send_keys(backspaces)
-        field.send_keys(str(field_content))
-        self.wait_for_input_field_content(field_name, field_content)
 
-    def fill_codemirror_area_with(self, field_content):
+        # Use send keys if input_keys true, else use javascript to set content
+        if input_keys:
+            backspaces = [Keys.BACKSPACE] * len(field.get_attribute('value'))
+            field.send_keys(backspaces)
+            field.send_keys(str(field_content))
+            self.wait_for_input_by_element(field, field_content)
+        else:
+            self.driver.execute_script("arguments[0].value = arguments[1]",
+                                       field, field_content)
+            # keycode 40 is for arrow down
+            self.js_send_key(field, Keys.ARROW_DOWN)
+
+            if key_after_input:
+                self.js_send_key(field, key_after_input)
+
+    def fill_input_by_field_name(self, field_name, field_content,
+                                 input_keys=False,
+                                 key_after_input=Keys.ARROW_DOWN,
+                                 loose_focus=False):
+        field = self.find_by_css_selector(
+            "input[name='" + field_name + "']:not(:disabled)")
+        self.fill_input(field, field_content, input_keys=input_keys,
+                        key_after_input=key_after_input)
+
+        if loose_focus:
+            self.js_loose_focus(field)
+
+    def fill_input_by_css_selector(self, css_selector, field_content,
+                                   input_keys=False,
+                                   key_after_input=Keys.ARROW_DOWN,
+                                   loose_focus=False):
+        field = self.find_by_css_selector(css_selector)
+        self.fill_input(field, field_content, input_keys=input_keys,
+                        key_after_input=key_after_input)
+
+        if loose_focus:
+            self.js_loose_focus(field)
+
+    def fill_codemirror_area_with(self, field_content, input_keys=False):
         def find_codemirror(driver):
             try:
                 driver.switch_to.default_content()
                 driver.switch_to_frame(
                     driver.find_element_by_tag_name("iframe"))
-                element = driver.find_element_by_xpath(
-                    "//pre[contains(@class,'CodeMirror-line')]/../../../"
-                    "*[contains(@class,'CodeMirror-code')]")
+                element = driver.find_element_by_css_selector(
+                    "#output-panel .CodeMirror")
                 if element.is_displayed() and element.is_enabled():
                     return element
             except (NoSuchElementException, WebDriverException):
                 return False
 
-        time.sleep(1)
-        WebDriverWait(self.driver, timeout=self.timeout, poll_frequency=0.01).\
-            until(find_codemirror, "Timed out waiting for codemirror "
-                                   "to appear").click()
-        time.sleep(1)
+        codemirror_ele = WebDriverWait(
+            self.driver, timeout=self.timeout, poll_frequency=0.01)\
+            .until(find_codemirror,
+                   "Timed out waiting for codemirror to appear")
 
-        action = ActionChains(self.driver)
-        action.send_keys(field_content)
-        action.perform()
+        time.sleep(1)
+        codemirror_ele.click()
+
+        # Use send keys if input_keys true, else use javascript to set content
+        if input_keys:
+            action = ActionChains(self.driver)
+            action.send_keys(field_content)
+            action.perform()
+        else:
+            self.driver.execute_script(
+                "arguments[0].CodeMirror.setValue(arguments[1]);"
+                "arguments[0].CodeMirror.setCursor("
+                "arguments[0].CodeMirror.lineCount(),0);",
+                codemirror_ele, field_content)
 
     def click_tab(self, tab_name):
         WebDriverWait(self.driver, 10).until(EC.element_to_be_clickable(
@@ -269,7 +369,15 @@ class PgadminPage:
 
         self.click_element(tab)
 
-    def wait_for_input_field_content(self, field_name, content):
+    def wait_for_input_by_element(self, element, content):
+        def input_field_has_content(driver):
+            return str(content) == element.get_attribute('value')
+
+        return self._wait_for(
+            "field to contain '" + str(content) + "'", input_field_has_content
+        )
+
+    def wait_for_input_field_content(self, field_name, content, wait=1):
         def input_field_has_content(driver):
             element = driver.find_element_by_xpath(
                 "//input[@name='" + field_name + "']")
@@ -277,8 +385,20 @@ class PgadminPage:
             return str(content) == element.get_attribute('value')
 
         return self._wait_for(
-            "field to contain '" + str(content) + "'", input_field_has_content
-        )
+            "field to contain '" + str(content) + "'", input_field_has_content,
+            wait)
+
+    def check_if_element_exist_by_xpath(self, xpath, timeout=5):
+        """This function will verify if an element exist and on that basis
+        will return True or False. Will handle exception internally"""
+        element_found = False
+        try:
+            WebDriverWait(self.driver, timeout, .01).until(
+                EC.visibility_of_element_located((By.XPATH, xpath)))
+            element_found = True
+        except Exception as e:
+            pass
+        return element_found
 
     def wait_for_element(self, find_method_with_args):
         def element_if_it_exists(driver):
@@ -286,7 +406,7 @@ class PgadminPage:
                 element = find_method_with_args(driver)
                 if element.is_displayed() and element.is_enabled():
                     return True
-            except NoSuchElementException:
+            except (NoSuchElementException, StaleElementReferenceException):
                 return False
 
         self._wait_for("element to exist", element_if_it_exists)
@@ -329,10 +449,10 @@ class PgadminPage:
     def wait_for_query_tool_loading_indicator_to_disappear(self):
         def spinner_has_disappeared(driver):
             try:
-                driver.find_element_by_xpath(
-                    "//*[@id='fetching_data' and @class='hide']"
+                spinner = driver.find_element_by_css_selector(
+                    "#editor-panel .pg-sp-container"
                 )
-                return False
+                return "d-none" in spinner.get_attribute("class")
             except NoSuchElementException:
                 # wait for loading indicator disappear animation to complete.
                 time.sleep(0.5)
